//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to impliment careful_rename
//

#include <cerrno>
#include <cstdio> // for rename
#include <unistd.h> // for unlink

#include <careful.h>
#include <quit.h>
#include <rcstring.h>


void
careful_rename(const rcstring &old_name, const rcstring &new_name)
{
    if (rename(old_name.c_str(), new_name.c_str()) < 0)
    {
	//
        // Get rid of the new file, because we are about to bail, and we
        // don't want to leave junk lying around.
	//
	int err = errno;
	unlink(old_name.c_str());
	errno = err;

	quitter.fatal_error_with_errno
	(
	    "rename(\"%s\", \"%s\")",
	    old_name.c_str(),
	    new_name.c_str()
	);
    }
}
