//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to implement the configuration::chroot method
//

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>

#include <configuration.h>
#include <quit.h>


bool
configuration::get_chroot()
{
    //
    // Ideally, this should default to true for maximum protection.
    //
    // Unfortunately, modern systems now make this a privileged
    // operation (because it can lead to root escalation) and thus
    // not universally available, which is a what a default of "true"
    // assumes.
    //
    return get_bool("chroot", false);
}


int
configuration::get_umask()
{
    return (077 & get_long("umask", 022));
}


void
configuration::chroot()
{
    if (get_chroot())
    {
	const rcstring &var(get_localstatedir());
	if (::chroot(var.c_str()))
	    quitter.fatal_error_with_errno("chroot(%s)", var.c_str());
	localstatedir_cache = "/";
	set("localstatedir", localstatedir_cache);
    }
    umask(get_umask());
}
