//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to impliment the file class
//

#pragma implementation "file"

#include <cctype>
#include <cstring>
#include <cstdio>

#include <cgi.h>
#include <configuration.h>
#include <file.h>
#include <input/file.h>
#include <link_tracker/null.h>
#include <output.h>
#include <rcstring/accumulator.h>
#include <relative_path.h>
#include <wiki_to/html.h>
#include <wiki_word.h>


file::~file()
{
}


file::file(const rcstring &arg) :
    user_path(arg)
{
}


void
file::request()
{
    const char *request_method = gateway.get_request_method();
    if (strcasecmp(request_method, "GET") == 0)
    {
	if (!gateway.viable_path_info())
	{
	    printf("Location: %s/index\n\n", gateway.get_script_name().c_str());
	    return;
	}
	get_request();
    }
    else if (strcasecmp(request_method, "POST") == 0)
    {
	gateway.read_post_data();
	post_request();
    }
    else if (strcasecmp(request_method, "HEAD") == 0)
    {
	head_request();
    }
    else
    {
	gateway.fatal_error("Request method \"%s\" unknown", request_method);
    }
}


static void
no_such_file()
{
    gateway.fatal_error
    (
	"%s %s: No such object",
	gateway.get_request_method(),
	gateway.get_path_info().c_str()
    );
}


void
file::get_request()
{
    no_such_file();
}


void
file::post_request()
{
    get_request();
}


void
file::head_request()
{
    no_such_file();
}


void
file::sidebar(output &out)
{
    rcstring width = config.get_sidebar_width();
    out << "<TD VALIGN=\"TOP\" CLASS=\"sidebar\" STYLE=\"width: "
	<< width
	<< "\">\n";
    input_file in(config.get_localstatedir() + "/sidebar.wiki");
    in.empty_if_absent();
    link_tracker_null noref(user_path);
    wiki_to_html translator("sidebar", in, out, noref);
    translator.translate();
    out << "<P CLASS=\"sidebar\">\n"
           "<A HREF=\""
        << relative_path(user_path, "/sidebar?edit")
	<< "\" CLASS=\"sidebar\">Edit</A> this\n"
	   "<A HREF=\""
        << relative_path(user_path, "/sidebar")
	<< "\" CLASS=\"sidebar\">sidebar</A>.\n"
	   "</P>\n";

    rcstring referred_to_by_path =
	config.get_localstatedir() + user_path + ".referred_to_by";
    rcstring_list referred_to_by;
    referred_to_by.read_from(referred_to_by_path);
    if (!referred_to_by.empty())
    {
	out << "<HR/>\nThis wiki page is referred to by\n";
	for (size_t j = 0; j < referred_to_by.size(); ++j)
	{
	    if (j)
	    {
		if (j + 1 == referred_to_by.size())
		    out << " and\n";
		else
		    out << ",\n";
	    }
	    const rcstring &other_path(referred_to_by[j]);
	    out << "<A HREF=\""
	       	<< relative_path(user_path, other_path)
		<< "\">"
		<< wiki_word_pretty(other_path)
		<< "</A>";
	}
	out << ".\n";
    }
    out << "</TD>\n";
}


static rcstring
remove_markup(const rcstring &s)
{
    rcstring_accumulator acc;
    const char *cp = s.c_str();
    int depth = 0;
    for (;;)
    {
	unsigned char c = *cp++;
	if (!c)
	    break;
	if (c == '<')
	    ++depth;
	if (!depth)
	    acc.push_back(c);
	if (c == '>' && depth > 0)
	    --depth;
    }
    while (acc.size() && isspace((unsigned char)acc.back()))
	acc.pop_back();
    return acc.mkstr();
}


void
file::layout_header(output &out, const rcstring &title)
{
    rcstring css_file = "/admin/" + config.get_style_sheet_name();
    rcstring title2 =
	(title[0] == '<' ? title : ("<H1>" + title.html_quote() + "</H1>"));
    out << "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"\">\n"
	   "<HTML><HEAD>\n"
           "<TITLE>"
	<< remove_markup(title2)
        << "</TITLE>\n"
           "<LINK REL=\"stylesheet\" HREF=\""
        << relative_path(user_path, css_file)
        << "\" TYPE=\"text/css\">\n"
           "</HEAD><BODY>\n";
    switch (config.get_sidebar_layout())
    {
    case configuration::sidebar_layout_none:
	break;

    case configuration::sidebar_layout_left:
	out << "<TABLE>\n"
	       "<TR>\n";
	sidebar(out);
	out << "<TD VALIGN=\"TOP\" CLASS=\"content\">\n";
	break;

    case configuration::sidebar_layout_right:
	out << "<TABLE>\n"
	       "<TR>\n"
	       "<TD VALIGN=\"TOP\">\n";
	break;
    }
    out << title2;
    if (!out.start_of_line())
	out.putch('\n');
}


void
file::layout_footer(output &out)
{
    switch (config.get_sidebar_layout())
    {
    case configuration::sidebar_layout_none:
	break;

    case configuration::sidebar_layout_left:
	out << "</TD>\n"
	       "</TR>\n"
	       "</TABLE>\n";
	break;

    case configuration::sidebar_layout_right:
	out << "</TD>\n";
	sidebar(out);
	out << "</TR>\n"
	       "</TABLE>\n";
	break;
    }
    out << "</BODY></HTML>\n";
}
