//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/file/admin.cc
//

#ifndef LIB_FILE_ADMIN_H
#define LIB_FILE_ADMIN_H

#pragma interface "file_admin"

#include <file.h>

/**
  * The file_admin class is used to represent the table-of-contents or
  * index file for the various pages with dynamic content.
  */
class file_admin:
    public file
{
public:
    /**
      * The destructor.
      */
    virtual ~file_admin();

    /**
      * The default constructor.
      */
    file_admin();

    /**
      * The factory class method is used to produce the appropriate file
      * instance based on the name of the administrative file.  Usually
      * these file have dynamic content, unlike wiki files which can be
      * cached.
      */
    static file *factory(const rcstring &name);

    // See base class for documentation.
    void get_request();

private:
    /**
      * The copy constructor.  Do not use.
      */
    file_admin(const file_admin &);

    /**
      * The assignment operator.  Do not use.
      */
    file_admin &operator=(const file_admin &);
};

#endif // LIB_FILE_ADMIN_H
