//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to impliment the file_factory class
//

#include <cassert>
#include <sys/types.h>
#include <sys/stat.h>

#include <configuration.h>
#include <file/regular.h>
#include <file/admin.h>
#include <wiki_word.h>


file *
file::factory(const rcstring &path)
{
    //
    // Directories are special-cased to refer to the index file within
    // them.  This is particularly relevant for the top-level page that
    // points to everything else.
    //
    assert(path[0] == '/');
    rcstring user_path = wiki_word_sanitizer(path);
    if (path.back() == '/')
    {
	user_path += "index";
    }

    //
    // Test here for special functions,
    // analogous to "about:*" in some web browsers.
    //
    if (user_path == "/admin")
	return file_admin::factory(user_path + "/index");
    if (0 == memcmp(user_path.c_str(), "/admin/", 7))
	return file_admin::factory(user_path);

    const rcstring &vardir = config.get_localstatedir();
    rcstring file_system_path = vardir + user_path;

    //
    // Catch any directories that may have slipped by until now.
    //
    struct stat st;
    if (lstat(file_system_path.c_str(), &st) == 0 && S_ISDIR(st.st_mode))
    {
	user_path += "/index";
	file_system_path += "/index";
    }

    //
    // Anything that isn't a special file (caught above) must be a
    // regular file.  Typically they have a "*.wiki" master and a
    // "*.html" cache.
    //
    return new file_regular(user_path, file_system_path);
}
