//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/file/literal.cc
//

#ifndef LIB_FILE_LITERAL_H
#define LIB_FILE_LITERAL_H

#pragma interface "file_literal"

#include <file.h>

/**
  * The file_literal class is used to represent a file which is exactly
  * named, and passed through unchanged.
  */
class file_literal:
    public file
{
public:
    /**
      * The destructor.
      */
    virtual ~file_literal();

    /**
      * The constructor.
      *
      * @param user_path
      *     The user-perception of the file's path.
      * @param file_system_path
      *     The name of the file to be copied to the output as a result
      *     of a GET request.
      */
    file_literal(const rcstring&user_path, const rcstring &file_system_path);

    // See base class for documentation.
    void get_request();

private:
    /**
      * The file_system_path instance variable is used to remember the
      * name of the file to be copied to the output as a result of a GET
      * request.
      */
    rcstring file_system_path;

    /**
      * The default constructor.  Do not use.
      */
    file_literal();

    /**
      * The copy constructor.  Do not use.
      */
    file_literal(const file_literal &);

    /**
      * The assignment operator.  Do not use.
      */
    file_literal &operator=(const file_literal &);
};

#endif // LIB_FILE_LITERAL_H
