//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to impliment the file_new_user class
//

#pragma implementation "file_new_user"

#include <cstdlib>
#include <ctime>
#include <unistd.h>

#include <cgi.h>
#include <file/new_user.h>
#include <output/stdout.h>
#include <user.h>
#include <wiki_word.h>


file_new_user::~file_new_user()
{
}


file_new_user::file_new_user() :
    file("/admin/new_user")
{
}


static bool
ip_address_is_blacklisted()
{
    // TODO: Need to implement this
    return false;
}


void
file_new_user::get_request()
{
    if (ip_address_is_blacklisted())
	get_request_deny();
    else
    {
	rcstring submit = gateway.get_variable("submit").downcase();
	if (submit.empty())
	    get_request_form();
	else
	    get_request_perform();
    }
}


void
file_new_user::get_request_deny()
{
    output_stdout out;
    out << "Content-Type: text/html\n\n";
    layout_header(out, "Create New User");
    out << "<P CLASS=\"warning\">You may not create new user accounts.</P>\n";
    layout_footer(out);
}


void
file_new_user::emit_form(output &out)
{
    out << "<FORM REQUEST_METHOD=\"POST\">\n"
           "<TABLE CLASS=\"administration\">\n"
           "<TR CLASS=\"administration\">\n";

    rcstring name = gateway.get_variable("name");
    out << "<TD CLASS=\"administration\">"
           "Choose a user name:"
           "</TD>\n"
           "<TD CLASS=\"administration\">"
           "<INPUT TYPE=\"TEXT\" SIZE=8 NAME=\"name\" MAXLENGTH=14"
	   ;
    if (!name.empty())
    {
	out << " VALUE=\"" << name << "\"";
    }
    out << ">"
           "</TD>\n"
           "<TD CLASS=\"administration\">"
           "This is the name other users of this site will see in file "
           "histories."
           "</TD>\n"
           "</TR>\n";

    rcstring fullname = gateway.get_variable("fullname");
    out << "<TD CLASS=\"administration\">"
           "Your full name:"
           "</TD>\n"
           "<TD CLASS=\"administration\">"
           "<INPUT TYPE=\"TEXT\" SIZE=20 NAME=\"fullname\" MAXLENGTH=60"
	   ;
    if (!fullname.empty())
    {
	out << " VALUE=\"" << fullname << "\"";
    }
    out << ">"
           "</TD>\n"
           "<TD CLASS=\"administration\">"
           "This name will not be disclosed to other users of this "
           "site by the wiki engine, although it may be used by the "
           "engine when creating templates of new pages for you to "
           "edit."
           "</TD>\n"
           "</TR>\n";

    rcstring email = gateway.get_variable("email");
    out << "<TD CLASS=\"administration\">"
           "Your email address:"
           "</TD>\n"
           "<TD CLASS=\"administration\">"
           "<INPUT TYPE=\"TEXT\" SIZE=20 NAME=\"email\" MAXLENGTH=60"
	   ;
    if (!email.empty())
    {
	out << " VALUE=\"" << email << "\"";
    }
    out << ">"
           "</TD>\n"
           "<TD CLASS=\"administration\">"
           "This name will not be disclosed to other users of this "
           "site by the wiki engine."
           "</TD>\n"
           "</TR>\n";

    rcstring pwd = gateway.get_variable("pwd1");
    out << "<TR CLASS=\"administration\">\n"
           "<TD CLASS=\"administration\">"
           "Choose a password:"
           "</TD>\n"
           "<TD CLASS=\"administration\">"
           "<INPUT TYPE=\"PASSWORD\" SIZE=8 NAME=\"pwd1\" MAXLENGTH=20";
    if (!pwd.empty())
    {
	out << " VALUE=\"" << pwd << "\"";
    }
    out << ">"
           "</TD>\n"
           "<TD CLASS=\"administration\" ROWSPAN=2>"
           "Your password will not be disclosed to any other users of "
	   "this site."
           "</TD>\n"
           "</TR>\n"

           "<TR CLASS=\"administration\">\n"
           "<TD CLASS=\"administration\">"
           "Confirm password:"
           "</TD>\n"
           "<TD CLASS=\"administration\">"
           "<INPUT TYPE=\"PASSWORD\" SIZE=8 NAME=\"pwd2\" MAXLENGTH=20";
    if (!pwd.empty())
    {
	out << " VALUE=\"" << pwd << "\"";
    }
    out << ">"
           "</TD>\n"
           "</TR>\n"

           "<TR CLASS=\"administration\">\n"
           "<TD CLASS=\"administration\" ALIGN=\"RIGHT\">"
	   "<INPUT TYPE=\"submit\" name=\"submit\" value=\"Create\">"
           "</TD>\n"
           "<TD CLASS=\"administration\">"
	   "<INPUT type=\"reset\" value=\"Reset\">"
           "</TD>\n"
           "</TR>\n"

           "</TABLE>\n"
           "</FORM>\n";
}

void
file_new_user::get_request_form()
{
    output_stdout out;
    out << "Content-Type: text/html\n\n";
    layout_header(out, "Create New User");
    emit_form(out);
    layout_footer(out);
}


static char
rndchar()
{
    return ("abcdefghijklmnopqrstuvwxyz"
	    "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
	    "0123456789./"[((rand() >> 7) & 63)]);
}


static rcstring
generate_key()
{
    //
    // I wonder what people will think is encoded in the
    // quickie-user-key cookie, when they haven't read this comment?
    // Make sure you make something up, something devious and sneaky,
    // but for goodness sake, don't tell them it's just random gibberish.
    //
    srand(time(0) + getpid());
    char buffer[21];
    for (int j = 0; j < 20; ++j)
	buffer[j] = rndchar();
    buffer[20] = 0;
    return buffer;
}


void
file_new_user::get_request_perform()
{
    rcstring_list errors;

    //
    // Confirm user name as acceptable.
    //
    rcstring fullname = gateway.get_variable("fullname");
    if (fullname.empty())
    {
	errors.push_back("You must supply your full name.");
    }

    //
    // Confirm email address as acceptable.
    //
    rcstring email = gateway.get_variable("email");
    if (email.empty())
    {
	errors.push_back("You must supply your email address.");
    }

    //
    // Confirm user name as acceptable.
    //
    rcstring name = gateway.get_variable("name");
    if (name.length() == 0)
    {
	errors.push_back("You must supply a user name.");
	name = "xxx";
    }
    else
    {
	rcstring name2 = wiki_word_sanitizer(name);
	if (name != name2)
	{
	    errors.push_back("Name contains inappropriate characters.");
	    name = name2;
	}
	if (name.length() < 3)
	{
            errors.push_back
    	    (
		"The user name is too short, "
		"it must be at least three characters."
	    );
	    name = (name + "xxx").substring(0, 3);
	}
	else if (name.length() > 14)
	{
	    errors.push_back("User name too long.");
	    name = name.substring(0, 14);
	}
    }

    if (errors.empty() && user_t::exists(name))
    {
	errors.push_back("User " + name + " already exists.");
	for (long k = 2; ; ++k)
	{
	    rcstring num(k);
	    size_t max = name.length();
	    if (max + num.length() > 14)
		max = 14 - num.length();
	    rcstring name2 = name.substring(0, max) + num;
	    if (!user_t::exists(name2))
	    {
		name = name2;
		break;
	    }
	}
    }
    gateway.set_variable("name", name);

    rcstring pwd = gateway.get_variable("pwd1");
    if (pwd != gateway.get_variable("pwd2"))
    {
	errors.push_back("Password mismatch, try again.");
	gateway.set_variable("pwd1", "");
    }

    output_stdout out;
    if (errors.empty())
    {
	srand(time(0) + getpid());
	char salt[2];
	salt[0] = rndchar();
	salt[1] = rndchar();
	rcstring cypher_text(crypt(pwd.c_str(), salt));

	user.default_settings();
	user.set("name", name);
	user.set("fullname", fullname);
	user.set("email", email);
	user.set("password", cypher_text);
	rcstring key = generate_key();
	user.set("key", key);
	user.flush();

	user.set_cookie(out);
	out << "Content-Type: text/html\n"
	       "\n";
	layout_header(out, "Create New User");
	out << "<P CLASS=\"administration\">"
	       "User "
	    << name
	    << " created successfully.</P>\n";
	layout_footer(out);
    }
    else
    {
	out << "Content-Type: text/html\n\n";
	layout_header(out, "Create New User");
	out << "<P CLASS=\"warning\">"
	    << errors.unsplit("\n")
	    << "</P>\n";
	emit_form(out);
	layout_footer(out);
    }
}
