//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/file/regular.cc
//

#ifndef LIB_FILE_REGULAR_H
#define LIB_FILE_REGULAR_H

#pragma interface "file_regular"

#include <string.h>
#include <file.h>

/**
  * The file_regular class is used to represent the interface to a
  * "regular" file, a plain ordinary text/html file.
  */
class file_regular:
    public file
{
public:
    /**
      * The destructor.
      */
    virtual ~file_regular();

    /**
      * The constructor.
      *
      * @param user_path
      *    The path of the file, as given in the PATH_INFO environment
      *    variable.
      * @param file_system_path
      *    The path of the file, after the "localstatedir" has been
      *    added to the user perception of the path.
      */
    file_regular(const rcstring &user_path, const rcstring &file_system_path);

    /**
      * The synthesize method is used to synthesize HTML from wiki text.
      * If it only ever called if the cached HTML file does not exist.
      *
      * @note
      *     The only reason this method is not private is so that
      *     quickie_prime can call it.  No other client may use this
      *     method.
      */
    void synthesize();

protected:
    // See base class for documentation.
    void get_request();

private:
    /**
      * The file_system_path instance variable is used to remember the
      * path of the file in the file system.
      */
    rcstring file_system_path;

    /**
      * The get request_html method is the usual way of emitting
      * content.  If the .html file is not present, it will be
      * regenerated from the .wiki file.
      */
    void get_request_html();

    /**
      * The get_request_edit method is used to emit a form for the user
      * to fill in which allows editing of the underlying .wiki file.
      */
    void get_request_edit();

    /**
      * The get_request_history method is used to emit a table of
      * previous page versions.
      */
    void get_request_history();

    /**
      * The get_request_preview method is used to emit a preview page
      * based on the form data in the post request.  Usually triggered
      * by using the "Preview" button in the form.
      */
    void get_request_preview();

    /**
      * The get_request_preview method is used to save an edited page
      * based on the form data in the post request.  Usually triggered
      * by using the "Save" button in the form.
      */
    void get_request_save();

    /**
      * The get_request_cancel method is used to abandon editing a page
      * Usually triggered by using the "Cancel" button in the form.
      */
    void get_request_cancel();

    /**
      * The default constructor.
      */
    file_regular();

    /**
      * The copy constructor.  Do not use.
      */
    file_regular(const file_regular &);

    /**
      * The assignment operator.  Do not use.
      */
    file_regular &operator=(const file_regular &);
};

#endif // LIB_FILE_REGULAR_H
