//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/input/crlf.cc
//

#ifndef LIB_INPUT_CRLF_H
#define LIB_INPUT_CRLF_H

#pragma interface "input_crlf"

#include <input.h>

/**
  * The input_crlf class is used to represent the state of an input
  * filter which maps CRLF sequences into LF sequences.
  */
class input_crlf:
    public input
{
public:
    /**
      * The destructor.
      */
    virtual ~input_crlf();

    /**
      * The constructor.
      *
      * @param deeper
      *     The deeper input from which this filter reads its data.
      */
    input_crlf(input &deeper);

    // See base class for documentation.
    size_t read_inner(void *data, size_t nbytes);

    // See base class for documentation.
    rcstring name();

private:
    /**
      * The deeper instance variable is used to remember the deeper
      * input from which this filter reads its data.
      */
    input *deeper;

    /**
      * The default constructor.  Do not use.
      */
    input_crlf();

    /**
      * The copy constructor.  Do not use.
      */
    input_crlf(const input_crlf &);

    /**
      * The assignment operator.  Do not use.
      */
    input_crlf &operator=(const input_crlf &);
};

#endif // LIB_INPUT_CRLF_H
