//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to impliment the input_crop class
//

#pragma implementation "input_crop"

#include <input/crop.h>


input_crop::~input_crop()
{
    if (delete_on_delete)
	delete deeper;
}


input_crop::input_crop(input &arg1, size_t arg2) :
    deeper(&arg1),
    delete_on_delete(false),
    length(arg2)
{
}


input_crop::input_crop(input *arg1, size_t arg2) :
    deeper(arg1),
    delete_on_delete(true),
    length(arg2)
{
}


size_t
input_crop::read_inner(void *vp, size_t nbytes)
{
    char *start = (char *)vp;
    char *data = start;
    while (length > 0)
    {
	size_t max = nbytes < length ? nbytes : length;
	size_t n = deeper->read(data, max);
	if (!n)
	    break;
	data += n;
	length -= n;
	nbytes -= n;
    }
    return (data - start);
}


rcstring
input_crop::name()
{
    return deeper->name();
}
