//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/input/crop.cc
//

#ifndef LIB_INPUT_CROP_H
#define LIB_INPUT_CROP_H

#pragma interface "input_crop"

#include <input.h>

/**
  * The input_crop class is used to represent an input filter which
  * crops out a chunk of input from a deeper input source.
  */
class input_crop:
    public input
{
public:
    /**
      * The destructor.
      */
    virtual ~input_crop();

    /**
      * The constructor.
      *
      * @param deeper
      *     The input source which this filter reads the data to be
      *     filtered.
      * @param length
      *     How much data (in bytes) to read from the deeper input
      *     before asserting end of file.
      */
    input_crop(input &deeper, size_t length);

    /**
      * The constructor.
      *
      * @param deeper
      *     The input source which this filter reads the data to be
      *     filtered.  Will be deleted by out destructor.
      * @param length
      *     How much data (in bytes) to read from the deeper input
      *     before asserting end of file.
      */
    input_crop(input *deeper, size_t length);

    // See base class for documentation.
    size_t read_inner(void *data, size_t nbytes);

    // See base class for documentation.
    rcstring name();

private:
    /**
      * The deeper instance variable is used to remember the input
      * source which this filter reads the data to be filtered.
      */
    input *deeper;

    /**
      * The delete_on_delete instance variable is sued to remember
      * whether or not we delete our deeper input in out destructor.
      */
    bool delete_on_delete;

    /**
      * The length instance variable is used to remember how much data
      * (in bytes) to read from the deeper input before asserting end of
      * file.
      */
    size_t length;

    /**
      * The default constructor.
      */
    input_crop();

    /**
      * The copy constructor.
      */
    input_crop(const input_crop &);

    /**
      * The assignment operator.
      */
    input_crop &operator=(const input_crop &);
};

#endif // LIB_INPUT_CROP_H
