//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to impliment the input_file class
//

#pragma implementation "input_file"

#include <cerrno>
#include <fcntl.h>
#include <unistd.h>

#include <input/file.h>


input_file::~input_file()
{
    if (fd >= 0)
    {
	if (close(fd) < 0)
	    fatal_error_with_errno("close");
	fd = -1;
    }
}


input_file::input_file(const rcstring &arg) :
    file_name(arg),
    fd(-1),
    length_cached(0),
    mod_time_cached(0)
{
}


size_t
input_file::read_inner(void *data, size_t nbytes)
{
    ssize_t result = ::read(get_fd(), data, nbytes);
    if (result < 0)
	fatal_error_with_errno("read");
    return result;
}


void
input_file::empty_if_absent()
{
    get_fd(false);
}


int
input_file::get_fd(bool must_exist)
{
    if (fd < 0)
    {
	fd = open(file_name.c_str(), O_RDONLY);
	if (fd < 0)
	{
	    if (!must_exist)
	    {
		if (errno != ENOENT)
		{
		    fatal_error_with_errno("open");
		}
		file_name = "/dev/null";
		fd = open(file_name.c_str(), O_RDONLY);
	    }
	    if (fd < 0)
		fatal_error_with_errno("open");
	}

	struct stat st;
	if (fstat(fd, &st) < 0)
	    fatal_error_with_errno("stat");
	length_cached = st.st_size;
	mod_time_cached = st.st_mtime;
    }
    return fd;
}


long
input_file::get_length()
{
    get_fd();
    return length_cached;
}


time_t
input_file::get_mod_time()
{
    get_fd();
    return mod_time_cached;
}


rcstring
input_file::name()
{
    return file_name;
}
