//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/input/file.cc
//

#ifndef LIB_INPUT_FILE_H
#define LIB_INPUT_FILE_H

#pragma interface "input_file"

#include <ctime>

#include <input.h>
#include <rcstring.h>

/**
  * The input_file class is used to represent an input stream read from
  * a regular file in the file system.
  */
class input_file:
    public input
{
public:
    /**
      * The destructor.
      */
    virtual ~input_file();

    /**
      * The constructor.
      *
      * @param file_name
      *     The name of the file to be read.
      */
    input_file(const rcstring &file_name);

    // See base class for documentation.
    size_t read_inner(void *data, size_t nbytes);

    /**
      * The empty_if_absent method is used to say that if the file is
      * not present, the behave as if the file <i>was</i> present but
      * simply empty.
      *
      * \note
      *     This method must be called before <i>any</i> data is read
      *     from the file.
      */
    void empty_if_absent();

    /**
      * The get_length method is used to obtain the length of the file
      * in bytes.
      */
    long get_length();

    /**
      * The get_mod_time method is used to obtain the time and date the
      * file was last modified.
      */
    time_t get_mod_time();

    // See base class for documentation.
    rcstring name();

private:
    /**
      * The file_name instance variable is used to remember the name of
      * the file to be read.
      */
    rcstring file_name;

    /**
      * The fd instance variable is used to remember the file descriptor
      * of the open file, or -1 if the file is not open.
      */
    int fd;

    /**
      * The get_fd method is used to obtain the file descriptor.  It
      * should always be used when you want the file descriptor for
      * something.
      */
    int get_fd(bool must_exist = true);

    /**
      * The length_cached instance variable is used to remember the
      * length of the input file in bytes.
      */
    long length_cached;

    /**
      * The mod_time_cached instance variable is used to remember the
      * last time the input file was modofied.
      */
    time_t mod_time_cached;

    /**
      * The default constructor.  Do not use.
      */
    input_file();

    /**
      * The copy constructor.  Do not use.
      */
    input_file(const input_file &);

    /**
      * The assignment operator.  Do not use.
      */
    input_file &operator=(const input_file &);
};

#endif // LIB_INPUT_FILE_H
