//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/input/gunzip.cc
//

#ifndef LIB_INPUT_GUNZIP_H
#define LIB_INPUT_GUNZIP_H

#pragma interface "input_gunzip"

#include <ac/zlib.h>

#include <input.h>

/**
  * The input_gunzip class is used to represent an input filter which
  * transparently gunzips an input stream.
  */
class input_gunzip:
    public input
{
public:
    /**
      * The destructor.
      */
    virtual ~input_gunzip();

    /**
      * The constructor.
      */
    input_gunzip(input *deeper, bool nuke = true);

    /**
      * The factor class method is used to look at an input stream and
      * see if it needs to be gunzipped or not.  It returns the inpit
      * argument if it does not, or it creates a filter if it does.
      */
    static input *factory(input *deeper);

    // See base class for documentation.
    size_t read_inner(void *data, size_t nbytes);

    // See base class for documentation.
    rcstring name();

private:
    /**
      * The deeper instance variable is used to remember where this
      * filter gets its input data from.
      */
    input *deeper;

    /**
      * The stream instance variable is used to remember an opaque block
      * of data for use by libz.
      */
    z_stream stream;

    /**
      * The z_eof instance variable is used to remember if we have
      * reached the end of the compressed data.
      */
    bool z_eof;

    /**
      * The crc instance variable is used to remember the running cyclic
      * redundancy check, used to confirm data integrity end we reach
      * the end of the compressed data.
      */
    uLong crc;

    /**
      * The pos instance variable is used to remember the "seek"
      * position withing the decompressed data.
      */
    long pos;

    /**
      * The buf instance variable is used to remember the location of
      * the data buffer used by libz.
      */
    Byte *buf;

    /**
      * The filename instance variable is used to remember the (cached)
      * value of the input file name, with any compression suffix removed.
      */
    rcstring filename;

    /**
      * The delete_deeper_on_close instance variable is used to rememer
      * whether or not to delete the deeper input in our destructor.
      */
    bool delete_deeper_on_close;

    /**
      * The zlib_fatal_error method is used to report fatal errors
      * coming out of the zlib engine.
      */
    void zlib_fatal_error(int err);

    /**
      * The get_long method is used to obtain the next four bytes of
      * deeper input, and turn them into a long.  They are little-endian
      * ordered.
      */
    long get_long();

    /**
      * The default constructor.  Do not use.
      */
    input_gunzip();

    /**
      * The copy constructor.  Do not use.
      */
    input_gunzip(const input_gunzip &);

    /**
      * The assignment operator.  Do not use.
      */
    input_gunzip &operator=(const input_gunzip &);
};

#endif // LIB_INPUT_GUNZIP_H
