//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/input/one_line.cc
//

#ifndef LIB_INPUT_ONE_LINE_H
#define LIB_INPUT_ONE_LINE_H

#pragma interface "input_one_line"

#include <input.h>

/**
  * The input_one_line class is used to represent an input filter which
  * reads as most a single line (up to the first newline) and then
  * returns end of file.
  */
class input_one_line:
    public input
{
public:
    /**
      * The destructor.
      */
    virtual ~input_one_line();

    /**
      * The constructor.
      *
      * @param deeper
      *     the place where this filter reads its input from.
      */
    input_one_line(input &deeper);

    // See base class for documentation.
    size_t read_inner(void *data, size_t nbytes);

    // See base class for documentation.
    rcstring name();

private:
    /**
      * The deeper instance variable is used to remember the place where
      * this filter reads its input from.
      */
    input *deeper;

    /**
      * The end_of_file instance variable is used to remember whether ot
      * not we have reached our pseudo end-of-file mark (a newline) yet.
      */
    bool end_of_file;

    /**
      * The deeper_getch method is used to read a character from the
      * deeper file, which respecting (and eventually setting) the
      * end-of-file indicator.
      */
    int deeper_getch();

    /**
      * The default constructor.  Do not use.
      */
    input_one_line();

    /**
      * The copy constructor.  Do not use.
      */
    input_one_line(const input_one_line &);

    /**
      * The assignment operator.  Do not use.
      */
    input_one_line &operator=(const input_one_line &);
};

#endif // LIB_INPUT_ONE_LINE_H
