//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to impliment the input_remove_comments class
//

#pragma implementation "input_remove_comments"

#include <cstdio>

#include <input/remove_comments.h>


input_remove_comments::~input_remove_comments()
{
}


input_remove_comments::input_remove_comments(input &arg) :
    deeper(&arg),
    state(state_start_of_line),
    line_number(0)
{
}


size_t
input_remove_comments::read_inner(void *void_data_p, size_t nbytes)
{
    char *begin = (char *)void_data_p;
    char *cp = begin;
    char *end = begin + nbytes;
    while (begin < end)
    {
	//
        // We defer incrementing the line number so that errors detected
        // at end-of-line are reported fro the correct line.
	//
	if (state == state_start_of_line)
	    ++line_number;

	int c = deeper->getch();
	if (c < 0)
	    break;
	switch ((unsigned char)c)
	{
	case '\n':
	    if (state == state_in_content)
		*cp++ = c;
	    state = state_start_of_line;
	    if (cp == begin)
		break;

	    //
            // We return now (reporting success) so that line numbers in
            // error messages can be against the correct line number.
	    //
	    return (cp - begin);

	case '#':
	    if (state == state_start_of_line)
		state = state_in_comment;
	    break;

	default:
	    if (state != state_in_comment)
	    {
		state = state_in_content;
		*cp++ = c;
	    }
	    break;
	}
    }
    return (cp - begin);
}


rcstring
input_remove_comments::name()
{
    if (line_number == 0)
	return deeper->name();
    char buf[20];
    snprintf(buf, sizeof(buf), ": %d", line_number);
    return (deeper->name() + rcstring(buf));
}
