//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/input/remove_comments.cc
//

#ifndef LIB_INPUT_REMOVE_COMMENTS_H
#define LIB_INPUT_REMOVE_COMMENTS_H

#pragma interface "input_remove_comments"

#include <input.h>

/**
  * The input_remove_comments class is used to represent
  */
class input_remove_comments:
    public input
{
public:
    /**
      * The destructor.
      */
    virtual ~input_remove_comments();

    /**
      * The constructor.
      *
      * @param deeper
      *     The source of input to be filtered to remove comments.
      */
    input_remove_comments(input &deeper);

    // See base class for documentation.
    size_t read_inner(void *data, size_t nbytes);

    // See base class for documentation.
    rcstring name();

private:
    /**
      * The deeper instance variable is used to remember the source of
      * input to be filtered to remove comments.
      */
    input *deeper;

    enum state_t
    {
	state_start_of_line,
	state_in_comment,
	state_in_content
    };

    /**
      * The state instance variable is used to remember what parse state
      * we are in at this position in the input.
      */
    state_t state;

    /**
      * The line_number instance variable is used to remember what line
      * we are up to in the input.
      */
    int line_number;

    /**
      * The default constructor.
      */
    input_remove_comments();

    /**
      * The copy constructor.
      */
    input_remove_comments(const input_remove_comments &);

    /**
      * The assignment operator.
      */
    input_remove_comments &operator=(const input_remove_comments &);
};

#endif // LIB_INPUT_REMOVE_COMMENTS_H
