//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/input/string.cc
//

#ifndef LIB_INPUT_STRING_H
#define LIB_INPUT_STRING_H

#pragma interface "input_string"

#include <input.h>
#include <rcstring.h>

/**
  * The input_string class is used to represent an input sopurce which
  * reads its data from a string.
  */
class input_string:
    public input
{
public:
    /**
      * The destructor.
      */
    virtual ~input_string();

    /**
      * The constructor.
      */
    input_string(const rcstring &text);

    // See base class for documentation.
    size_t read_inner(void *data, size_t nbytes);

    // See base class for documentation.
    rcstring name();

private:
    /**
      * The text instance variable is used to remember the string which
      * forms the input stream.
      */
    rcstring text;

    /**
      * The pos instance variable is used to remember the current
      * position within the input stream.
      */
    size_t pos;

    /**
      * The default constructor.  Do not use.
      */
    input_string();

    /**
      * The copy constructor.  Do not use.
      */
    input_string(const input_string &);

    /**
      * The assignment operator.  Do not use.
      */
    input_string &operator=(const input_string &);
};

#endif // LIB_INPUT_STRING_H
