//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to impliment the input_svt_checkout class
//

#pragma implementation "input_svt_checkout"

#include <input/crop.h>
#include <input/file.h>
#include <input/gunzip.h>
#include <input/verify_checksum.h>
#include <input/svt_checkout.h>
#include <output/null.h>
#include <rfc822.h>


input_svt_checkout::~input_svt_checkout()
{
    delete src4_p;
    delete src3_p;
    delete src2_p;
    delete src1_p;
}


input_svt_checkout::input_svt_checkout(const rcstring &filename,
	const rcstring &version) :
    src1_p(new input_file(filename)),
    src2_p(new input_gunzip(src1_p, false)),
    src3_p(0),
    src4_p(0)
{
    for (;;)
    {
	//
	// Read an RFC 822 header from the input.
	//
	rfc822 header;
	header.load(*src2_p);

	//
	// If the version matches, extract it to a file.
	//
	long content_length = header.get_long("content-length");
	src3_p = new input_crop(*src2_p, content_length);
	unsigned long checksum = header.get_ulong("checksum");
	src4_p = new input_verify_checksum(*src3_p, checksum);
	if (version.empty() || version == header.get("version"))
	    return;

	//
	// Throw away the file contents.
	//
	output_null bit_bucket;
	bit_bucket << *src4_p;

	delete src4_p;
	src4_p = 0;
	delete src3_p;
	src3_p = 0;

	//
	// If there is no more input, we are done.
	//
	if (src2_p->at_end())
	{
	    src1_p->fatal_error("version %s not found", version.c_str());
	    // NOTREACHED
	}
    }
}


rcstring
input_svt_checkout::name()
{
    return src1_p->name();
}


size_t
input_svt_checkout::read_inner(void *data, size_t nbytes)
{
    if (!src4_p)
	return 0;
    return src4_p->read(data, nbytes);
}
