//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/input/uudecode.cc
//

#ifndef LIB_INPUT_UUDECODE_H
#define LIB_INPUT_UUDECODE_H

#pragma interface "input_uudecode"

#include <input.h>

/**
  * The input_uudecode class is used to represent an input filter which
  * transparently decodes uuencode(1)ed files.
  */
class input_uudecode:
    public input
{
public:
    /**
      * The destructor.
      */
    virtual ~input_uudecode();

    /**
      * The constructor.
      */
    input_uudecode(input *);

    // See base class for documentation.
    size_t input_uudecode::read_inner(void *data, size_t nbytes);

    // See base class for documentation.
    rcstring name();

private:
    input *deeper;
    bool close_on_close;
    long pos;
    int state;
    unsigned char etab[64];
    unsigned char itab[256];
    int checksum;
    int padding;

    /**
      * The default constructor.  Do not use.
      */
    input_uudecode();

    /**
      * The copy constructor.  Do not use.
      */
    input_uudecode(const input_uudecode &);

    /**
      * The assignment operator.  Do not use.
      */
    input_uudecode &operator=(const input_uudecode &);
};

#endif // LIB_INPUT_UUDECODE_H
