//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to impliment the input_verify_checksum class
//

#pragma implementation "input_verify_checksum"

#include <ac/zlib.h>

#include <input/verify_checksum.h>


input_verify_checksum::~input_verify_checksum()
{
}


input_verify_checksum::input_verify_checksum(input &arg1, unsigned long arg2) :
    deeper(&arg1),
    checksum_given(arg2),
    checksum_calculated(adler32(0L, Z_NULL, 0))
{
}


size_t
input_verify_checksum::read_inner(void *data, size_t nbytes)
{
    size_t result = deeper->read(data, nbytes);
    if (!result)
    {
	if (checksum_calculated != checksum_given)
	{
	    deeper->fatal_error
	    (
		"checksum mismatch (%08lX != %08lX)",
		checksum_given,
		checksum_calculated
	    );
	    // NOTREACHED
	}
	return 0;
    }
    checksum_calculated = adler32(checksum_calculated, (Bytef *)data, result);
    return result;
}


rcstring
input_verify_checksum::name()
{
    return deeper->name();
}
