//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/link_tracker/null.cc
//

#ifndef LIB_LINK_TRACKER_NULL_H
#define LIB_LINK_TRACKER_NULL_H

#pragma interface "link_tracker_null"

#include <link_tracker.h>

/**
  * The link_tracker_null class is used to represent a link tracker that
  * doesn't actually do anything.  It throws away all the information
  * passed to it.
  */
class link_tracker_null:
    public link_tracker
{
public:
    /**
      * The destructor.
      */
    virtual ~link_tracker_null();

    /**
      * The constructor.
      *
      * @param user_path
      *     The path of the file, as given in the PATH_INFO environment
      *     variable.
      */
    link_tracker_null(const rcstring &user_path);

    // See base class for documentation.
    void internal_link_exists(const rcstring &destination);

    // See base class for documentation.
    void internal_link_new(const rcstring &destination);

private:
    /**
      * The default constructor.  Do not use.
      */
    link_tracker_null();

    /**
      * The copy constructor.  Do not use.
      */
    link_tracker_null(const link_tracker_null &);

    /**
      * The assignment operator.  Do not use.
      */
    link_tracker_null &operator=(const link_tracker_null &);
};

#endif // LIB_LINK_TRACKER_NULL_H
