//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to impliment the mime_lex class
//

#pragma implementation "mime_lex"

#include <cctype>

#include <mime_lex.h>
#include <rcstring/accumulator.h>


mime_lex::~mime_lex()
{
}


mime_lex::mime_lex(const rcstring &arg) :
    text(arg),
    position(0),
    token(token_junk)
{
}


char
mime_lex::getch()
{
    if (position >= text.size())
	return 0;
    return text[position++];
}


void
mime_lex::ungetch(char c)
{
    if (c && position > 0)
	--position;
}


void
mime_lex::next_token()
{
    static rcstring_accumulator acc;
    acc.clear();
    value.clear();
    for (;;)
    {
	unsigned char c = getch();
	switch (c)
	{
	case '\0':
	    token = token_end_of_string;
	    return;

	case ' ':
	case '\t':
	case '\n':
	    break;

	case ';':
	    token = token_semicolon;
	    return;

	case '=':
	    token = token_equals;
	    return;

	case '"':
	    for (;;)
	    {
		c = getch();
		switch (c)
		{
		case '"':
		    break;

		default:
		    if (!isprint(c))
		    {
		case '\0':
			token = token_junk;
			return;
		    }
		    // fall through...

		case 'a': case 'b': case 'c': case 'd': case 'e': case 'f':
		case 'g': case 'h': case 'i': case 'j': case 'k': case 'l':
		case 'm': case 'n': case 'o': case 'p': case 'q': case 'r':
		case 's': case 't': case 'u': case 'v': case 'w': case 'x':
		case 'y': case 'z':
		case 'A': case 'B': case 'C': case 'D': case 'E': case 'F':
		case 'G': case 'H': case 'I': case 'J': case 'K': case 'L':
		case 'M': case 'N': case 'O': case 'P': case 'Q': case 'R':
		case 'S': case 'T': case 'U': case 'V': case 'W': case 'X':
		case 'Y': case 'Z':
		case '0': case '1': case '2': case '3': case '4':
		case '5': case '6': case '7': case '8': case '9':
		case '_': case '-': case '.': case ' ':
		    acc.push_back(c);
		    continue;
		}
		break;
	    }
	    value = acc.mkstr();
	    token = token_string;
	    return;

	default:
	    if (!isprint(c))
	    {
		token = token_junk;
		return;
	    }
	    // fall through...

	case 'a': case 'b': case 'c': case 'd': case 'e': case 'f': case 'g':
	case 'h': case 'i': case 'j': case 'k': case 'l': case 'm': case 'n':
	case 'o': case 'p': case 'q': case 'r': case 's': case 't': case 'u':
	case 'v': case 'w': case 'x': case 'y': case 'z':
	case 'A': case 'B': case 'C': case 'D': case 'E': case 'F': case 'G':
	case 'H': case 'I': case 'J': case 'K': case 'L': case 'M': case 'N':
	case 'O': case 'P': case 'Q': case 'R': case 'S': case 'T': case 'U':
	case 'V': case 'W': case 'X': case 'Y': case 'Z':
	case '0': case '1': case '2': case '3': case '4':
	case '5': case '6': case '7': case '8': case '9':
	case '_': case '-': case '.':
	    for (;;)
	    {
		acc.push_back(c);
		c = getch();
		switch (c)
		{
		default:
		    if (!isprint(c))
		    {
		case '\0':
		case '\t':
		case '\n':
		case ' ':
		case '"':
		case '=':
		case ';':
			ungetch(c);
			break;
	    	    }
		    // fall through...

		case 'a': case 'b': case 'c': case 'd': case 'e': case 'f':
		case 'g': case 'h': case 'i': case 'j': case 'k': case 'l':
		case 'm': case 'n': case 'o': case 'p': case 'q': case 'r':
		case 's': case 't': case 'u': case 'v': case 'w': case 'x':
		case 'y': case 'z':
		case 'A': case 'B': case 'C': case 'D': case 'E': case 'F':
		case 'G': case 'H': case 'I': case 'J': case 'K': case 'L':
		case 'M': case 'N': case 'O': case 'P': case 'Q': case 'R':
		case 'S': case 'T': case 'U': case 'V': case 'W': case 'X':
		case 'Y': case 'Z':
		case '0': case '1': case '2': case '3': case '4':
		case '5': case '6': case '7': case '8': case '9':
		case '_': case '-': case '.':
		    continue;
		}
		break;
	    }
	    value = acc.mkstr();
	    token = token_name;
	    return;
	}
    }
}


const char *
mime_lex::get_token_name(token_t n)
{
    switch (n)
    {
    case token_end_of_string:
	return "end of string";

    case token_name:
	return "name";

    case token_string:
	return "string";

    case token_equals:
	return "equals";

    case token_semicolon:
	return "semicolon";

    case token_junk:
	return "junk";
    }
    return "???";
}
