//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/mime_lex.cc
//

#ifndef LIB_MIME_LEX_H
#define LIB_MIME_LEX_H

#pragma interface "mime_lex"

#include <rcstring.h>

/**
  * The mime_lex class is used to represent the parse state of a lexical
  * analyzer for parsing MIME headers.
  */
class mime_lex
{
public:
    /**
      * The destructor.
      */
    virtual ~mime_lex();

    /**
      * The constructor.
      */
    mime_lex(const rcstring &text);

    enum token_t
    {
	token_end_of_string,
	token_name,
	token_string,
	token_equals,
	token_semicolon,
	token_junk
    };

    /**
      * The cur_token method is sued to fetch the value of the current token.
      */
    token_t cur_token() const { return token; }

    /**
      * the get_value method is used to get the value of the current token.
      */
    const rcstring &get_value() const { return value; }

    /**
      * The next_token is used to fetch the next token in the input stream.
      */
    void next_token();

    /**
     * The get_token_name class method is used to obtain a human
     * readable string corresponding to the given token.
     */
    static const char *get_token_name(token_t tnum);

private:
    rcstring text;
    size_t position;
    token_t token;
    rcstring value;

    char getch();
    void ungetch(char);

    /**
      * The default constructor.
      */
    mime_lex();

    /**
      * The copy constructor.
      */
    mime_lex(const mime_lex &);

    /**
      * The assignment operator.
      */
    mime_lex &operator=(const mime_lex &);
};

#endif // LIB_MIME_LEX_H
