//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to impliment the mkdir_p class
//

#include <cerrno>
#include <cstring>
#include <sys/types.h>
#include <sys/stat.h>

#include <mkdir_p.h>
#include <quit.h>
#include <rcstring.h>


void
mkdir_above(const rcstring &pathname)
{
    const char *base = pathname.c_str();
    const char *cp = base;
    for (;;)
    {
	const char *ep = strchr(cp, '/');
	if (!ep)
	    return;
	if (ep >= base + 2)
	{
	    rcstring path(base, ep - base);
	    if (mkdir(path.c_str(), 0777) < 0)
	    {
		switch (errno)
		{
		case EEXIST:
		    //
                    // This is the error we expect for directories which
                    // already exist.
		    //
		    break;

#if 0
		case EACCES:
		case EPERM:
		case EROFS:
		    //
		    // Some unix implementations test for existence *after*
		    // they check for permissions.  Thus we have to ignore
		    // errors relating to directories which already exist,
		    // but which we would not have been allowed to create if
		    // they didn't.
		    //
		    break;
#endif

		default:
		    //
		    // And everything else kills us.
		    //
		    quitter.fatal_error_with_errno
		    (
			"mkdir \"%s\"",
			path.c_str()
		    );
		    // NOTREACHED
		}
	    }
	}
	cp = ep + 1;
    }
}
