//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to impliment the output_file class
//

#pragma implementation "output_file"

#include <cerrno>
#include <cstring>
#include <fcntl.h>
#include <unistd.h>
// #include <sys/types.h>
// #include <sys/stat.h>

#include <mkdir_p.h>
#include <output/file.h>


output_file::~output_file()
{
    //
    // We have to call this here, because the base classes's destructor
    // is too late, because this destructor will have finished running
    // by then.
    //
    flush();

    if (fd >= 0)
    {
	if (close(fd) < 0)
	    oops("close");
	fd = -1;
    }
}


void
output_file::oops(const char *function)
{
    int err = errno;
    unlink(file_name.c_str());
    errno = err;
    fatal_error_with_errno("%s \"%s\"", function, file_name.c_str());
}


output_file::output_file(const rcstring &arg) :
    file_name(arg),
    fd(-1),
    block_size(1 << 13),
    bol(true)
{
}


void
output_file::mkdir_p()
{
    if (fd >= 0)
	return;

    //
    // It may be necessary to create some directories before you can
    // write the file.
    //
    mkdir_above(file_name);
}


int
output_file::get_fd()
{
    if (fd < 0)
    {
	fd = open(file_name.c_str(), O_WRONLY | O_CREAT | O_TRUNC, 0666);
	if (fd < 0)
	    oops("open");
	struct stat st;
	if (fstat(fd, &st) < 0)
	    oops("stat");
	if (st.st_blksize > 0)
	    block_size = st.st_blksize;
    }
    return fd;
}


void
output_file::write_inner(const void *data, size_t nbytes)
{
    if (nbytes)
    {
	if (::write(get_fd(), data, nbytes) < 0)
	    oops("write");
	bol = (((char *)data)[nbytes - 1] == '\n');
    }
}


size_t
output_file::get_block_size()
{
    get_fd();
    return block_size;
}


bool
output_file::start_of_line_inner()
    const
{
    return bol;
}


rcstring
output_file::name()
{
    return file_name;
}
