//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/output/file.cc
//

#ifndef LIB_OUTPUT_FILE_H
#define LIB_OUTPUT_FILE_H

#pragma interface "output_file"

#include <output.h>
#include <rcstring.h>

/**
  * The output_file class is used to represent writing data to a file in
  * the file system.
  */
class output_file:
    public output
{
public:
    /**
      * The destructor.
      */
    virtual ~output_file();

    /**
      * The constructor.
      *
      * @param file_name
      *     The name of the file which output is to be written to.
      */
    output_file(const rcstring &file_name);

    // See base class for documentation.
    void write_inner(const void *data, size_t nbytes);

    // See base class for documentation.
    size_t get_block_size();

    // See base class for documentation.
    bool start_of_line_inner() const;

    //
    // The mkdir_p method may be used to create the intermediate
    // directories if necessary.  This is like the "mkdir -p" command.
    //
    // @note
    //     This method *must* be called before the first write method
    //     call, otherwise it will be ignored (you already have the file
    //     open).
    //
    void mkdir_p();

    // See base class for documentation.
    rcstring name();

private:
    /**
      * The file_name instance variable is used to remember the name of
      * the file which output is to be written to.
      */
    rcstring file_name;

    /**
      * The fd instance variabel is used to remember the file descriptor
      * of the open file, or -1 if the file is not open.
      */
    int fd;

    /**
      * The get_fd method is used to get the file descriptor to use.
      * Don't access the fd instance variable directly.  This allows
      * deferred opens, so you can call the mkdir_p method first.
      */
    int get_fd();

    /**
      * The block_size instance variabel is used to remember the
      * preferred block size of this file.
      */
    size_t block_size;

    /**
      * The oops method is used to report fatal errors.
      * This method does not return.
      */
    void oops(const char *);

    /**
      * The bol instance variable is used to remember whether or not we
      * are positioned at the start of a line.
      */
    bool bol;

    /**
      * The default constructor.  Do not use.
      */
    output_file();

    /**
      * The copy constructor.  Do not use.
      */
    output_file(const output_file &);

    /**
      * The assignment operator.  Do not use.
      */
    output_file &operator=(const output_file &);
};

#endif // LIB_OUTPUT_FILE_H
