//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/output/gzip.cc
//

#ifndef LIB_OUTPUT_GZIP_H
#define LIB_OUTPUT_GZIP_H

#pragma interface "output_gzip"

#include <ac/zlib.h>

#include <output.h>

/**
  * The output_gzip class is used to represent an output filter which
  * compresses the data before writing it to the deeper output stream.
  */
class output_gzip:
    public output
{
public:
    /**
      * The destructor.
      */
    virtual ~output_gzip();

    /**
      * The constructor.
      *
      * \param deeper
      *     the output stream this filter will write its output to.
      * \param close_on_close
      *     whether or not the deeper output stream should be deleted on
      *     the destructor.
      */
    output_gzip(output *deeper, bool close_on_close = true);

    // See base class for documentation.
    rcstring name();

    // See base class for documentation.
    void write_inner(const void *data, size_t nbytes);

    // See base class for documentation.
    bool start_of_line_inner() const;

private:
    /**
      * The deeper instance variable is used to remember the output
      * stream this filter will write its output to.
      */
    output *deeper;

    /**
      * The close_on_close instance variable is used to remember whether
      * or not the deeper output stream should be deleted on the
      * destructor.
      */
    bool close_on_close;

    /**
      * The stream instance variable is used to remember somthign that
      * the gzip code wants to remember.  It is opaque to us.
      */
    z_stream stream;

    /**
      * The outbuf instance variable is used to remember the buffered
      * output data.
      */
    Byte *outbuf;

    /**
      * The crc instance variable is used to remember the crc32 of the
      * uncompressed data.
      */
    uLong crc;

    /**
      * The pos instance variable is used to remember the current output
      * position.
      */
    long pos;

    /**
      * The bol instance variable is used to remember whether or not the
      * output is positioned at the beginning of a lone.
      */
    bool bol;

    /**
      * The drop_dead method is used to report a fatal error from the
      * gzip engine.
      */
    void drop_dead(int err);

    /**
      * The default constructor.  Do not use.
      */
    output_gzip();

    /**
      * The copy constructor.  Do not use.
      */
    output_gzip(const output_gzip &);

    /**
      * The assignment operator.  Do not use.
      */
    output_gzip&operator=(const output_gzip &);
};

#endif // LIB_OUTPUT_GZIP_H
