//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to impliment the output_html_quote class
//

#pragma implementation "output_html_quote"

#include <cctype>

#include <output/html_quote.h>


output_html_quote::~output_html_quote()
{
    flush();
}


output_html_quote::output_html_quote(output &arg) :
    deeper(arg),
    bol(true)
{
}


rcstring
output_html_quote::name()
{
    return deeper.name();
}


void
output_html_quote::write_inner(const void *data, size_t nbytes)
{
    const unsigned char *s = reinterpret_cast<const unsigned char *>(data);
    const unsigned char *end = s + nbytes;
    while (s < end)
    {
	unsigned char c = *s++;
	switch (c)
	{
	case '\n':
	    deeper.putch(c);
	    bol = true;
	    break;

	case ' ':
	case '\t':
	    deeper.putch(c);
	    bol = false;
	    break;

	case '&':
	    deeper.puts("&amp;");
	    bol = false;
	    break;

	case '<':
	    deeper.puts("&lt;");
	    bol = false;
	    break;

	case '>':
	    deeper.puts("&gt;");
	    bol = false;
	    break;

	case '"':
	    deeper.puts("&quot;");
	    bol = false;
	    break;

	default:
	    // C locale
	    if (isprint(c))
		deeper.putch(c);
	    else
		deeper.printf("&#%d;", c);
	    bol = false;
	    break;
	}
    }
}


bool
output_html_quote::start_of_line_inner()
    const
{
    return bol;
}
