//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/output/html_quote.cc
//

#ifndef LIB_OUTPUT_HTML_QUOTE_H
#define LIB_OUTPUT_HTML_QUOTE_H

#pragma interface "output_html_quote"

#include <output.h>

/**
  * The output_html_quote class is used to represent an output filter
  * which quotes characters which are special to HTML, so that they are
  * represented appropriately on the user's browser.
  */
class output_html_quote:
    public output
{
public:
    /**
      * The destructor.
      */
    virtual ~output_html_quote();

    /**
      * The constructor.
      *
      * @param deeper
      *     where this filter sends its output.
      */
    output_html_quote(output &deeper);

    // See base class for documentation.
    rcstring output_html_quote::name();

    // See base class for documentation.
    void write_inner(const void *data, size_t nbytes);

    // See base class for documentation.
    bool start_of_line_inner() const;

private:
    /**
      * The deeper instance variable is used to remember where this
      * filter sends its output.
      */
    output &deeper;

    /**
      * The bol instance variable is used to remember whether or not the
      * current output position is at the beginning of a line.
      */
    bool bol;

    /**
      * The default constructor.
      */
    output_html_quote();

    /**
      * The copy constructor.
      */
    output_html_quote(const output_html_quote &);

    /**
      * The assignment operator.
      */
    output_html_quote &operator=(const output_html_quote &);
};

#endif // LIB_OUTPUT_HTML_QUOTE_H
