//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/output/string.cc
//

#ifndef LIB_OUTPUT_STRING_H
#define LIB_OUTPUT_STRING_H

#pragma interface "output_string"

#include <output.h>
#include <rcstring/accumulator.h>

/**
  * The output_string class is used to represent an output stream which
  * is written to a buffer, and eventually becomes a string.
  */
class output_string:
    public output
{
public:
    /**
      * The destructor.
      */
    virtual ~output_string();

    /**
      * The default constructor.
      */
    output_string();

    /**
      * The mkstr method may be used to turn the accumulated text into a
      * string.  It doesn't reset.
      */
    rcstring mkstr() { flush(); return acc.mkstr(); }

    /**
      * The clear method may be used to discard the text accumulated in
      * the buffer to date.
      */
    void clear() { flush(); acc.clear(); }

    // See base class for documentation.
    void write_inner(const void *data, size_t nbytes);

    // See base class for documentation.
    bool start_of_line_inner() const;

    // See base class for documentation.
    rcstring name();

private:
    /**
      * The acc instance variable is used to remember the text output so far.
      */
    rcstring_accumulator acc;

    /**
      * The copy constructor.  Do not use.
      */
    output_string(const output_string &);

    /**
      * The assignment operator.  Do not use.
      */
    output_string &operator=(const output_string &);
};

#endif // LIB_OUTPUT_STRING_H
