//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to impliment the quit class
//

#pragma implementation "quit"

#include <cerrno>
#include <cstdarg>
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <grp.h>
#include <pwd.h>
#include <unistd.h>

#include <quit.h>


quit::quit()
{
}


quit::quit(const quit &arg)
{
}


quit &
quit::operator=(const quit &arg)
{
    return *this;
}


quit::~quit()
{
}


void
quit::fatal_error(const char *fmt, ...)
{
    va_list ap;
    va_start(ap, fmt);
    fatal_error_v(fmt, ap);
    va_end(ap);
    exit(1);
}


void
quit::fatal_error_v(const char *fmt, va_list ap)
{
    message_v(fmt, ap);
    exit(1);
}


void
quit::fatal_error_with_errno(const char *fmt, ...)
{
    va_list ap;
    va_start(ap, fmt);
    fatal_error_with_errno_v(fmt, ap);
    va_end(ap);
    exit(1);
}


void
quit::fatal_error_with_errno_v(const char *fmt, va_list ap)
{
    int err = errno;
    char buffer[1024];
    vsnprintf(buffer, sizeof(buffer), fmt, ap);

    char user[30];
    char group[30];
    char id[60];
    id[0] = 0;
    switch (err)
    {
    case EPERM:
    case EACCES:
#ifndef DO_NOT_USE_GETPWUID
	struct passwd *pw = getpwuid(geteuid());
	if (pw)
	    snprintf(user, sizeof(user), "user %s", pw->pw_name);
	else
#endif
	    snprintf(user, sizeof(user), "uid %d", geteuid());
#ifndef DO_NOT_USE_GETPWUID
	struct group *gr = getgrgid(getegid());
	if (pw)
	    snprintf(group, sizeof(group), "group %s", gr->gr_name);
	else
#endif
	    snprintf(group, sizeof(group), "gid %d", geteuid());
	snprintf(id, sizeof(id), " [%s, %s]", user, group);
	break;
    }

    fatal_error("%s: %s%s", buffer, strerror(err), id);
    exit(1);
}


void
quit::warning(const char *fmt, ...)
{
    va_list ap;
    va_start(ap, fmt);
    warning_v(fmt, ap);
    va_end(ap);
}


void
quit::warning_v(const char *fmt, va_list ap)
{
    char buf[1024];
    vsnprintf(buf, sizeof(buf), fmt, ap);
    message("warning: %s", buf);
}


void
quit::message(const char *fmt, ...)
{
    va_list ap;
    va_start(ap, fmt);
    message_v(fmt, ap);
    va_end(ap);
}


void
quit::exit(int exit_status)
{
    atexit.run(exit_status);
    exit_inner(exit_status);

    //
    // GCC is brain-dead, it doesn't take note of the NORETURN attribute
    // for virtual functions.  This next line is necessry to silence a
    // spurious warning.
    //
    ::exit(exit_status);
}


void
quit::register_atexit(quit_atexit *p)
{
    atexit.push_back(p);
}
