//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to impliment the rcstring_dirname class
//

#include <rcstring.h>


rcstring
rcstring::dirname()
    const
{
    if (empty())
	return ".";

    const char *begin = c_str();
    const char *end = begin + size();

    //
    // Ignore trailing '/' characters.
    //
    while (end > begin + 1 && end[-1] == '/')
	--end;

    //
    // If all that is left is a single slash,
    // the return root ("/").
    //
    if (end - begin == 1 && *begin == '/')
	return "/";

    //
    // Now we have to find the last slash.
    //
    const char *cp = end;
    for (;;)
    {
	//
	// If path does not contain a slash,
	// dirname returns the string "."
	//
	if (cp == begin)
	    return ".";

	--cp;
	if (*cp == '/')
	{
	    while (cp > begin && cp[-1] == '/')
		--cp;
	    break;
	}
    }

    //
    // Build the result.
    //
    return rcstring(begin, cp - begin);
}
