//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/recent.cc
//

#ifndef LIB_RECENT_H
#define LIB_RECENT_H

#pragma interface "recent"

#include <ctime>

#include <rcstring.h>

class output; // forward

/**
  * The recent class is used to represent a record containing a file
  * name and a time last modified.
  */
class recent
{
public:
    /**
      * The destructor.
      */
    virtual ~recent();

    /**
      * The default constructor.  Do not use.
      */
    recent();

    /**
      * The constructor.
      *
      * @param user_path
      *     the user-preception of the file's path.
      * @param last_modified
      *     when the file was last modified.
      */
    recent(const rcstring &user_path, time_t last_modified);

    /**
      * The copy constructor.
      */
    recent(const recent &);

    /**
      * The assignment operator.
      */
    recent &operator=(const recent &);

    /**
      * The get_last_modified method is used to obtain the time the file
      * was last modified.
      *
      * @returns
      *     time_t, the time the file lwas last modified.
      * @note
      *     This method is supplied principally for sorting; no other
      *     code should be calling it.
      */
    time_t get_last_modified() const { return last_modified; }

    /**
      * The get_date method is used to obtain a string containing the
      * date the file was last modified.
      *
      * @returns
      *     a string, containing the date, but not the time.
      */
    rcstring get_date() const;

    /**
      * The get_time method is used to obtain a string containing the
      * date the file was last modified.
      *
      * @returns
      *     a string, containing the time, but not the date.
      */
    rcstring get_time() const;

    /**
      * The print method is used to print the file and its links.
      */
    void print(output &os) const;

private:
    /**
      * The user_path instance variable is used to remember the
      * user-preception of the file's path.
      */
    rcstring user_path;

    /**
      * The last_modified instance variable is used to remember when the
      * file was last modified.
      */
    time_t last_modified;
};

#endif // LIB_RECENT_H
