//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to impliment the recent_list class
//

#pragma implementation "recent_list"

#include <cassert>
#include <cstdlib>

#include <configuration.h>
#include <output.h>
#include <recent/list.h>


recent_list::~recent_list()
{
    delete [] file;
}


recent_list::recent_list() :
    nfiles(0),
    nfiles_max(0),
    file(0)
{
}


void
recent_list::push_back(const recent &arg)
{
    if (nfiles >= nfiles_max)
    {
	size_t new_nfiles_max = nfiles_max * 2 + 16;
	recent *new_file = new recent [new_nfiles_max];
	for (size_t j = 0; j < nfiles; ++j)
	    new_file[j] = file[j];
	delete [] file;
	file = new_file;
	nfiles_max = new_nfiles_max;
    }
    file[nfiles++] = arg;
}


static int
cmp(const void *va, const void *vb)
{
    const recent *a = reinterpret_cast<const recent *>(va);
    const recent *b = reinterpret_cast<const recent *>(vb);
    if (a->get_last_modified() > b->get_last_modified())
	return -1;
    if (a->get_last_modified() < b->get_last_modified())
	return 1;
    return 0;
}


void
recent_list::sort()
{
    qsort(file, nfiles, sizeof(file[0]), cmp);
}


void
recent_list::print(output &os)
    const
{
    os << "<TABLE CLASS=\"administration\">\n";
    rcstring prev_date;
    size_t max = config.get_recent_limit();
    if (max > size())
	max = size();
    for (size_t j = 0; j < size(); ++j)
    {
	const recent &page = nth(j);
	rcstring date = page.get_date();
	if (date != prev_date)
	{
	    os << "<TR CLASS=\"administration\">"
		  "<TD COLSPAN=4 CLASS=\"administration\">"
		  "<H2 CLASS=\"administration\">"
	       << date
	       << "</H2></TD></TR>\n";
	    prev_date = date;
	}
	page.print(os);
    }
    os << "</TABLE>\n";
}


const recent &
recent_list::nth(size_t n)
    const
{
    assert(n < nfiles);
    return file[n];
}
