//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/recent/list.cc
//

#ifndef LIB_RECENT_LIST_H
#define LIB_RECENT_LIST_H

#pragma interface "recent_list"

#include <recent.h>

/**
  * The recent_list class is used to represent a list of files.  They
  * will eventually be worted by their last modified times, and then
  * printed.
  */
class recent_list
{
public:
    /**
      * The destructor.
      */
    virtual ~recent_list();

    /**
      * The default constructor.
      */
    recent_list();

    /**
      * The push_back method is used to append another file to the list
      * of recently modified files.
      */
    void push_back(const recent &arg);

    void sort();

    void print(output &os) const;

    size_t size() const { return nfiles; }

    const recent &nth(size_t n) const;

    const recent &operator[](size_t n) const { return nth(n); }

private:
    size_t nfiles;
    size_t nfiles_max;
    recent *file;

    /**
      * The copy constructor.
      */
    recent_list(const recent_list &);

    /**
      * The assignment operator.
      */
    recent_list &operator=(const recent_list &);
};

#endif // LIB_RECENT_LIST_H
