//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to impliment the relative_path class
//

#include <cassert>
#include <cstring>

#include <relative_path.h>
#include <rcstring/accumulator.h>


rcstring
relative_path(const rcstring &from, const rcstring &to)
{
    const char *from_p = from.c_str();
    const char *to_p = to.c_str();
    assert(*from_p == '/');
    ++from_p;
    assert(*to_p == '/');
    ++to_p;

    //
    // First we have to eliminate the common directory portions.
    //
    for (;;)
    {
	const char *ep = strchr(from_p, '/');
	if (!ep)
	{
            // Easy case: the destination is below the exact same
            // directory as the source.
	    return to_p;
	}
	++ep;
	size_t len = ep - from_p;
	if (0 != memcmp(from_p, to_p, len))
	    break;
	from_p = ep;
	to_p += len;
    }

    //
    // Now we construct the rest by adding "../" as required.  We need
    // as many ..s as there are directories left in the "from" path,
    // then we simply append the remaining "to" path, and we are done.
    //
    static rcstring_accumulator acc;
    acc.clear();
    for (;;)
    {
	const char *ep = strchr(from_p, '/');
	if (!ep)
	{
	    acc.push_back(to_p);
	    return acc.mkstr();
	}
	acc.push_back("../", 3);
	from_p = ep + 1;
    }
}
