//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/tree_walk.cc
//

#ifndef LIB_TREE_WALK_H
#define LIB_TREE_WALK_H

#pragma interface "tree_walk"

#include <rcstring.h>

class tree_walk_functor; // forward

/**
  * The tree_walk class is used to represent the current state of
  * walking down a wiki tree from the root and out to all the leaves.
  * Only ".wiki" file are considered.
  */
class tree_walk
{
public:
    /**
      * The destructor.
      */
    virtual ~tree_walk();

    /**
      * The constructor.
      */
    tree_walk(const rcstring &root = "/");

    /**
      * The descend method is used to walk the tree below the root.
      *
      * @param inspector
      *     The object to be called when a suitable file is found.
      * @returns
      *     If a functor returns false, the tree walk will cease immediately.
      */
    bool descend(tree_walk_functor &inspector);

    /**
      * The set_sort_by_name method is used to turn on name sorting,
      * so that the file sare visited in order of theor names, in
      * case-insensitive ascending lexicographical order.
      */
    void set_sort_by_name() { sort_by_name = true; }

private:
    /**
      * The root instance variable is used to remember the base of the
      * directory tree being walked.
      */
    rcstring root;

    /**
      * The sort_by_name instance variable is used to remember whether
      * or not files should be sorted by name.  Defaults to false.
      */
    bool sort_by_name;

    /**
      * The descend method is used to walk the tree below the root.
      *
      * @param path
      *     The sub-path below the root walked so far.
      * @param inspector
      *     The object to be called when a suitable file is found.
      * @returns
      *     If a functor returns false, the tree walk will cease immediately.
      */
    bool descend(const rcstring &path, tree_walk_functor &inspector);

    /**
      * The copy constructor.  Do not use.
      */
    tree_walk(const tree_walk &);

    /**
      * The assignment operator.  Do not use.
      */
    tree_walk &operator=(const tree_walk &);
};

#endif // LIB_TREE_WALK_H
