//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/tree_walk/functor.cc
//

#ifndef LIB_TREE_WALK_FUNCTOR_H
#define LIB_TREE_WALK_FUNCTOR_H

#pragma interface "tree_walk_functor"

#include <tree_walk.h>

/**
  * The tree_walk_functor class is used to represent and abstract
  * interface to an object which can be called like a function, for the
  * purposes of walking the wiki directory tree.
  */
class tree_walk_functor
{
public:
    /**
      * The destructor.
      */
    virtual ~tree_walk_functor();

    /**
      * The default constructor.
      */
    tree_walk_functor();

    /**
      * The call operator is used to have the functor do some work.
      * Each derived class must implement this operator.
      *
      * @param path
      *    The user perceived path (i.e. the contents if PATH_INFO).
      * @param st
      *    The file status information of the .wiki file.
      * @returns
      *     boolean; true if successful, false if unsuccessful.
      *     If false, this will cause the whole tree walk to abort.
      */
    virtual bool operator()(const rcstring &path, const struct stat &st) = 0;

private:
    /**
      * The copy constructor.  Do not use.
      */
    tree_walk_functor(const tree_walk_functor &);

    /**
      * The assignment operator.  Do not use.
      */
    tree_walk_functor &operator=(const tree_walk_functor &);
};

#endif // LIB_TREE_WALK_FUNCTOR_H
