//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to impliment the tree_walk_functor_catalogue class
//

#pragma implementation "tree_walk_functor_catalogue"

#include <cassert>
#include <cctype>

#include <tree_walk/functor/catalogue.h>
#include <output.h>
#include <relative_path.h>
#include <wiki_word.h>

class output; // forward


tree_walk_functor_catalogue::~tree_walk_functor_catalogue()
{
}


tree_walk_functor_catalogue::tree_walk_functor_catalogue()
{
}


bool
tree_walk_functor_catalogue::operator()(const rcstring &user_path,
    const struct stat &st)
{
    pages.push_back(user_path);
    return true;
}


void
tree_walk_functor_catalogue::print(output &out)
    const
{
    //
    // We want a bunch of internal links to each letter.
    //
    out << "<P CLASS=\"administration\" STYLE=\"text-align: center;\">";
    char letter = 0;
    for (size_t j = 0; j < pages.size(); ++j)
    {
	const rcstring &page = pages[j];
	assert(page[0] == '/');
	if (page[1] == letter)
	    continue;
	if (letter)
	    out << " -\n";
	letter = page[1];
	unsigned char c = letter;
	if (islower(c))
	    c = toupper(c);
	out << "<A HREF=\"#" << c << "\" CLASS=\"administration\">"
	    << c << "</A>";
    }
    out << "</P>\n";

    //
    // And now all the links, with letter headings.
    //
    int para_state = 0;
    letter = 0;
    for (size_t k = 0; k < pages.size(); ++k)
    {
	const rcstring &page = pages[k];
	assert(page[0] == '/');
	if (page[1] != letter)
	{
	    if (para_state)
		out << "</P>\n";
	    letter = page[1];
	    unsigned char c = letter;
	    if (islower(c))
		c = toupper(c);
	    out << "<H2 CLASS=\"administration\">- <A NAME=\""
		<< c
		<< "\" CLASS=\"administration\">"
		<< c
		<< "</A> -</H2>\n"
	           "<P CLASS=\"administration\">\n";
	    para_state = 1;
	}
	if (para_state == 1)
	    para_state = 2;
	else
	    out << ",\n";
	out << "<A HREF=\""
	    << relative_path("/admin/catalogue", page).url_quote()
	    << "\" CLASS=\"administration\">"
	    << wiki_word_pretty(page)
	    << "</A>"
	    ;
    }
    if (para_state)
	out << "</P>\n";
}
