//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/tree_walk/functor/catalogue.cc
//

#ifndef LIB_TREE_WALK_FUNCTOR_CATALOGUE_H
#define LIB_TREE_WALK_FUNCTOR_CATALOGUE_H

#pragma interface "tree_walk_functor_catalogue"

#include <rcstring/list.h>
#include <tree_walk/functor.h>

/**
  * The tree_walk_functor_catalogue class is used to represent a
  * callable object which prints a catalogue of all wiki pages, sorted
  * by name.
  */
class tree_walk_functor_catalogue:
    public tree_walk_functor
{
public:
    /**
      * The destructor.
      */
    virtual ~tree_walk_functor_catalogue();

    /**
      * The default constructor.
      */
    tree_walk_functor_catalogue();

    // See base class for documentation.
    bool operator()(const rcstring &path, const struct stat &st);

    /**
      * The print method is used to print the file information, as a row
      * in an HTML table.
      */
    void print(output &os) const;

private:
    rcstring_list pages;

    /**
      * The copy constructor.  Do not use.
      */
    tree_walk_functor_catalogue(const tree_walk_functor_catalogue &);

    /**
      * The assignment operator.  Do not use.
      */
    tree_walk_functor_catalogue &operator=(const tree_walk_functor_catalogue &);
};

#endif // LIB_TREE_WALK_FUNCTOR_CATALOGUE_H
