//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/tree_walk/functor/recent.cc
//

#ifndef LIB_TREE_WALK_FUNCTOR_RECENT_H
#define LIB_TREE_WALK_FUNCTOR_RECENT_H

#pragma interface "tree_walk_functor_recent"

#include <tree_walk/functor.h>
#include <recent/list.h>

class output; // forward

/**
  * The tree_walk_functor_recent class is used to represent callable
  * object which prints a catalogue of all wiki pages, sorted by time
  * last modified, most recent to least recent.
  */
class tree_walk_functor_recent:
    public tree_walk_functor
{
public:
    /**
      * The destructor.
      */
    virtual ~tree_walk_functor_recent();

    /**
      * The default constructor.
      */
    tree_walk_functor_recent();

    // See base class for documentation.
    bool operator()(const rcstring &path, const struct stat &st);

    /**
      * The print method is used to print a summary of the files, once
      * the tree descent is completed.
      *
      * @param os
      *     This is the output stream to write the summary to.
      */
    void print(output &os);

private:
    /**
      * The pages instance variable is used to remember the list of wiki
      * pages names and theor mode times.  Eventually it will be sorted
      * and printed.
      */
    recent_list pages;

    /**
      * The copy constructor.  Do not use.
      */
    tree_walk_functor_recent(const tree_walk_functor_recent &);

    /**
      * The assignment operator.  Do not use.
      */
    tree_walk_functor_recent &operator=(const tree_walk_functor_recent &);
};

#endif // LIB_TREE_WALK_FUNCTOR_RECENT_H
