//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/wiki_mode.cc
//

#ifndef LIB_WIKI_MODE_H
#define LIB_WIKI_MODE_H

#pragma interface "wiki_mode"

#include <format_printf.h>

class output; // forward
class rcstring; // forward

/**
  * The wiki_mode class is used to represent and abstract concept of an
  * output style setting, such as italics or bold.
  */
class wiki_mode
{
public:
    /**
      * The destructor.
      */
    virtual ~wiki_mode();

    /**
      * The constructor.
      *
      * @param op
      *     Where to send the output.
      */
    wiki_mode(output *op);

    /**
      * The begin method is used to write the text to begin this mode.
      */
    virtual void begin() = 0;

    /**
      * The end method is used to write the text to end this mode.
      */
    virtual void end() = 0;

    enum type_t
    {
	type_anchor,
	type_bold,
	type_heading,
	type_italics,
	type_paragraph,
	type_preformatted,
	type_typewriter,
    };

    /**
      * The get_type method is used to get the type of this instance.
      * (RTTI wasn't useful in this context.)
      */
    virtual type_t get_type() const = 0;

protected:
    /**
      * The write method is used to write strings to begin and end this
      * mode.
      *
      * @param s
      *     The string to be written.
      */
    void write(const char *s);

    /**
      * The write method is used to write strings to begin and end this
      * mode.
      *
      * @param s
      *     The string to be written.
      */
    void write(const rcstring &s);

    /**
      * The bol method is used to force the output position to be the
      * beginnig of a line.
      */
    void bol();

    /**
      * The printf method may be used to write formatted data to the
      * output.  See printf(3) for a description of the arguments.
      */
    void printf(const char *fmt, ...)                   FORMAT_PRINTF(2, 3);

    /**
      * The get_output_name method is used to obtainb the name of the
      * output stream (probably a file, but not always).
      */
    rcstring get_output_name();

private:
    /**
      * The op instance variable is used to remember where to send the
      * output wen writing the begin nignand ending for this mode.
      */
    output *op;

    /**
      * The default constructor.  Do not use.
      */
    wiki_mode();

    /**
      * The copy constructor.  Do not use.
      */
    wiki_mode(const wiki_mode &);

    /**
      * The assignment operator.  Do not use.
      */
    wiki_mode &operator=(const wiki_mode &);
};

#endif // LIB_WIKI_MODE_H
