//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to impliment the wiki_mode_anchor class
//

#pragma implementation "wiki_mode_anchor"

#include <cstring>
#include <sys/types.h>
#include <sys/stat.h>

#include <cgi.h>
#include <configuration.h>
#include <link_tracker.h>
#include <wiki_mode/anchor.h>
#include <relative_path.h>
#include <rcstring/accumulator.h>
#include <wiki_word.h>


wiki_mode_anchor::~wiki_mode_anchor()
{
}


wiki_mode_anchor::wiki_mode_anchor(output *arg1, link_tracker &tracker,
	const rcstring &arg3, const rcstring &arg4) :
    wiki_mode(arg1),
    from(tracker.get_user_path()),
    url(arg3),
    css_class_name(arg4),
    external(false),
    exists(true),
    self_reference(false)
{
    external = !!strchr(url.c_str(), ':');
    if (external)
    {
	//
	// Let the tracker know what we are dealing with.
	//
	tracker.external_link(url);
    }
    else
    {
	url = wiki_word_sanitizer(url);
	if (url[0] != '/')
	    url = "/" + url;
	if (url.back() == '/')
	    url += "index";
	if (url == "/admin")
	{
	    url = "/admin/index";
	    exists = true;
	}
	else if (url.starts_with("/admin/"))
	{
	    exists = true;
	}
	else
	{
	    rcstring file_system_path =
		config.get_localstatedir() + url + ".wiki";
	    struct stat st;
	    if (lstat(file_system_path.c_str(), &st) >= 0)
	    {
		exists = true;
	    }
	    else
	    {
		exists = false;
		file_system_path = config.get_localstatedir() + url;
		if
		(
		    lstat(file_system_path.c_str(), &st) >= 0
		&&
		    S_ISDIR(st.st_mode)
		)
		{
		    url += "/index";
		    file_system_path =
			config.get_localstatedir() + url + ".wiki";
		    if
		    (
			lstat(file_system_path.c_str(), &st) >= 0
		    &&
			S_ISREG(st.st_mode)
		    )
		    {
			exists = true;
		    }
		}
	    }
	}
	self_reference = (url == from);

	//
	// Let the tracker know what we are dealing with.
	//
	if (!self_reference && !url.starts_with("/admin/"))
	{
	    if (exists)
		tracker.internal_link_exists(url);
	    else
		tracker.internal_link_new(url);
	}
    }
}


void
wiki_mode_anchor::begin()
{
    if (external)
    {
	write("<A\nHREF=\"");
	// Note: the user gave us this URL text,
	// we will assume it is already properly quoted.
	write(url);
	write("\"\nCLASS=\"");
	write(css_class_name);
	write("\">");
    }
    else if (self_reference)
    {
	// Do nothing.
    }
    else if (exists)
    {
	write("<A\nHREF=\"");
	write(relative_path(from, url));
	write("\"\nCLASS=\"");
	write(css_class_name);
	write("\">");
    }
    else
    {
	//
        // Underline broken internal links, they are probably links to
        // pages the user is about to write.
	//
	write("<SPAN CLASS=\"");
	write(css_class_name);
	write("\"\nSTYLE=\"text-decoration: underline\">");
    }
}


void
wiki_mode_anchor::end()
{
    if (external)
    {
	write("<IMG\nSRC=\"");
	write(relative_path(from, "/admin/external.png"));
	write("\"\nCLASS=\"");
	write(css_class_name);
	write("\" ALT=\"[]\"\nWIDTH=5 HEIGHT=6 STYLE=\"border: none\"></A>");
    }
    else if (self_reference)
    {
	// Do nothing.
    }
    else if (!exists)
    {
	write("</SPAN><A\nHREF=\"");
	write(relative_path(from, url + "?edit"));
	write("\"\nCLASS=\"");
	write(css_class_name);
	write("\">?</A>");
    }
    else
    {
	write("</A>");
    }
}


wiki_mode::type_t
wiki_mode_anchor::get_type()
    const
{
    return type_anchor;
}
