//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/wiki_mode/anchor.cc
//

#ifndef LIB_WIKI_MODE_ANCHOR_H
#define LIB_WIKI_MODE_ANCHOR_H

#pragma interface "wiki_mode_anchor"

#include <wiki_mode.h>
#include <rcstring.h>

class link_tracker; // forward

/**
  * The wiki_mode_anchor class is used to represent a text mode where
  * the destination of an anchor is known, and we are currently
  * processing the linked text.
  */
class wiki_mode_anchor:
    public wiki_mode
{
public:
    /**
      * The destructor.
      */
    virtual ~wiki_mode_anchor();

    /**
      * The constructor.
      *
      * @param op
      *     where to send output.
      * @param tracker
      *     A reference to an object interested in tracking linbks
      *     between wiki pages.  It also knows the user-path of the page
      *     containing the link.
      * @param url
      *     The link destination.
      * @param css_class_name
      *     The CSS style sheet name for this element.
      */
    wiki_mode_anchor(output *op, link_tracker &tracker, const rcstring &url,
	const rcstring &css_class_name);

    // See base class for documentation.
    void begin();

    // See base class for documentation.
    void end();

    // See base class for documentation.
    type_t get_type() const;

    /**
      * The url_sanitizer class method is used to render a "wiki word"
      * as an acceptable URL and file system path.  It does this by
      * turning all non alpha numeric characters into underscores, with
      * the exception of slash, the file system path separator.
      * Multiplke redundant underscores are omitted.
      *
      * @param arg
      *     The string to be sanitized.
      */
    rcstring url_sanitizer(const rcstring &arg);

private:
    /**
      * The user's perception of the path to the wiki page.  In other
      * words, the PATH_INFO passed to this CGI.
      */
    rcstring from;

    /**
      * The url instance variable is used to remember the URL which is
      * the destination for the link.
      */
    rcstring url;

    /**
      * The css_class_name instance variable is used to remember the CSS
      * style sheet name for this element.
      */
    rcstring css_class_name;

    /**
      * The external instance variable is used to remember whether or
      * not the URL is an external link.
      */
    bool external;

    /**
      * The exists instance variable is used to remember whether or not
      * the .wiki file of an internal links exists or not.
      */
    bool exists;

    /**
      * The self_reference instance variable is used to remember whether
      * or not this link is a reference to its own document.
      */
    bool self_reference;

    /**
      * The default constructor.  Do not use.
      */
    wiki_mode_anchor();

    /**
      * The copy constructor.  Do not use.
      */
    wiki_mode_anchor(const wiki_mode_anchor &);

    /**
      * The assignment operator.  Do not use.
      */
    wiki_mode_anchor &operator=(const wiki_mode_anchor &);
};

#endif // LIB_WIKI_MODE_ANCHOR_H
