//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/wiki_mode/simple.cc
//

#ifndef LIB_WIKI_MODE_SIMPLE_H
#define LIB_WIKI_MODE_SIMPLE_H

#pragma interface "wiki_mode_simple"

#include <rcstring.h>
#include <wiki_mode.h>

/**
  * The wiki_mode_simple class is used to represent a generalised simple
  * mode which has uncomplicated element begin and end tags.
  */
class wiki_mode_simple:
    public wiki_mode
{
public:
    /**
      * The destructor.
      */
    virtual ~wiki_mode_simple();

    /**
      * The constructor.
      * @param op
      *     Where to send the output.
      * @param element_name
      *     the name of the HTML element.
      * @param class_name
      *     The CSS style sheet class name.
      */
    wiki_mode_simple(output *op, const rcstring &element_name,
	const rcstring &class_name);

    // See base class for documentation.
    void begin();

    // See base class for documentation.
    void end();

private:
    /**
      * The element_name instance variable is used to remember the name
      * of the HTML element.
      */
    rcstring element_name;

    /**
      * The class_name instance variable is used to remember the CSS
      * style sheet class name.
      */
    rcstring class_name;

    /**
      * The default constructor.  Do not use.
      */
    wiki_mode_simple();

    /**
      * The copy constructor.  Do not use.
      */
    wiki_mode_simple(const wiki_mode_simple &);

    /**
      * The assignment operator.  Do not use.
      */
    wiki_mode_simple &operator=(const wiki_mode_simple &);
};

#endif // LIB_WIKI_MODE_SIMPLE_H
