//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/wiki_mode/stack.cc
//

#ifndef LIB_WIKI_MODE_STACK_H
#define LIB_WIKI_MODE_STACK_H

#pragma interface "wiki_mode_stack"

#include <cstddef>

#include <wiki_mode.h>

/**
  * The wiki_mode_stack class is used to represent
  */
class wiki_mode_stack
{
public:
    /**
      * The destructor.
      */
    virtual ~wiki_mode_stack();

    /**
      * The default constructor.
      */
    wiki_mode_stack();

    /**
      * The push_back method is used to add another mode to the end of
      * the mode stack.
      */
    void push_back(wiki_mode *);

    /**
      * The pop_back method is used to remove a mode from the end of the
      * mode stack.  It retuns the last mode, or NULL if the stack was
      * empty.
      */
    wiki_mode *pop_back();

    /**
      * The contains method is used to determin if a mode stack contains
      * at least once instance of the given type.
      */
    bool contains(wiki_mode::type_t) const;

    /**
      * The empty method is used to determine whther the mode stack is
      * empty or not.
      */
    bool empty() const { return (nitems == 0); }

    /**
      * The size method is used to determine how many items are
      * currently in the stack.
      */
    size_t size() const { return nitems; }

private:
    /**
      * The nitems instance variable is used to remember the number of
      * items on the stack.
      */
    size_t nitems;

    /**
      * The nitems_max instance variable is used to remember the number
      * of items allocated in the item array.
      */
    size_t nitems_max;

    /**
      * The item instance variable is used to remember the address of
      * the base of a dynamically alloocated array of pointers to modes.
      */
    wiki_mode **item;

    /**
      * The copy constructor.  Do not use.
      */
    wiki_mode_stack(const wiki_mode_stack &);

    /**
      * The assignment operator.  Do not use.
      */
    wiki_mode_stack &operator=(const wiki_mode_stack &);
};

#endif // LIB_WIKI_MODE_STACK_H
