//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to impliment the wiki_to_html class
//

#pragma implementation "wiki_to_html"

#include <cctype>

#include <output.h>
#include <wiki_mode/anchor.h>
#include <wiki_mode/paragraph/html.h>
#include <wiki_mode/simple/bold.h>
#include <wiki_mode/simple/heading.h>
#include <wiki_mode/simple/italics.h>
#include <wiki_mode/simple/preformatted.h>
#include <wiki_mode/simple/typewriter.h>
#include <wiki_to/html.h>


wiki_to_html::~wiki_to_html()
{
}


wiki_to_html::wiki_to_html(const rcstring &arg1, input &arg2, output &arg3,
	link_tracker &arg4) :
    wiki_to(arg2, arg3),
    css_class_name(arg1),
    tracker(arg4)
{
}


wiki_mode *
wiki_to_html::italics_factory()
{
    return new wiki_mode_simple_italics(osp, css_class_name);
}


wiki_mode *
wiki_to_html::bold_factory()
{
    return new wiki_mode_simple_bold(osp, css_class_name);
}


wiki_mode *
wiki_to_html::typewriter_factory()
{
    return new wiki_mode_simple_typewriter(osp, css_class_name);
}


wiki_mode *
wiki_to_html::anchor_factory(const rcstring &destination)
{
    return new wiki_mode_anchor(osp, tracker, destination, css_class_name);
}


wiki_mode *
wiki_to_html::heading_factory(int level)
{
    return new wiki_mode_simple_heading(osp, level, css_class_name);
}


wiki_mode *
wiki_to_html::preformatted_factory()
{
    return new wiki_mode_simple_preformatted(osp, css_class_name);
}


wiki_to *
wiki_to_html::self_factory(input &arg1, output &arg2)
{
    return new wiki_to_html(css_class_name, arg1, arg2, tracker);
}


wiki_mode *
wiki_to_html::paragraph_factory()
{
    return new wiki_mode_paragraph_html(osp, css_class_name);
}


void
wiki_to_html::putch(char cc)
{
    unsigned char c = cc;
    switch (c)
    {
    case '"':
	osp->puts("&quot;");
	break;

    case '&':
	osp->puts("&amp;");
	break;

    case '<':
	osp->puts("&lt;");
	break;

    case '>':
	osp->puts("&gt;");
	break;

    case ' ':
    case '\t':
    case '\n':
	osp->putch(c);
	break;

    default:
	if (isprint(c))
	    osp->putch(c);
	else
	    osp->printf("&#%d;", c);
	break;
    }
}
