//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/wiki_to/html.cc
//

#ifndef LIB_WIKI_TO_HTML_H
#define LIB_WIKI_TO_HTML_H

#pragma interface "wiki_to_html"

#include <rcstring.h>
#include <wiki_to.h>

class link_tracker; // forward

/**
  * The wiki_to_html class is used to represent a wiki page translator
  * which produces HTML.
  */
class wiki_to_html:
    public wiki_to
{
public:
    /**
      * The destructor.
      */
    virtual ~wiki_to_html();

    /**
      * The default constructor.
      *
      * @param css_class_name
      *     The base name of the CSS classes produced by the translation.
      * @param is
      *     The input file to read.
      * @param os
      *     The output stream to write.  It's probably a file, but it
      *     could be anything.
      * @param tracker
      *     A reference to an object which tracks the links from the
      *     translation to other files.
      */
    wiki_to_html(const rcstring &css_class_name, input &is, output &os,
	link_tracker &tracker);

    // See base class for documentation.
    wiki_mode *italics_factory();

    // See base class for documentation.
    wiki_mode *bold_factory();

    // See base class for documentation.
    wiki_mode *typewriter_factory();

    // See base class for documentation.
    wiki_mode *anchor_factory(const rcstring &destination);

    // See base class for documentation.
    wiki_mode *heading_factory(int level);

    // See base class for documentation.
    wiki_mode *preformatted_factory();

    // See base class for documentation.
    wiki_mode *paragraph_factory();

    // See base class for documentation.
    wiki_to *self_factory(input &is, output &os);

    // See base class for documentation.
    void putch(char c);

private:
    /**
      * The css_class_name instance variable is used to remember the
      * base of the CSS class names.
      */
    rcstring css_class_name;

    /**
      * The tracker instance variable is used to remember a reference to
      * an object which tracks the links from the translation to other
      * files.
      *
      * The tracker also knows the user's perception of the page's
      * path.  It is used to insert relative links into the generated
      * text, rather than absolute links which change depending on what
      * interface you are using.
      */
    link_tracker &tracker;

    /**
      * The copy constructor.
      */
    wiki_to_html(const wiki_to_html &);

    /**
      * The assignment operator.
      */
    wiki_to_html &operator=(const wiki_to_html &);
};

#endif // LIB_WIKI_TO_HTML_H
