//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to impliment the wiki_to_look_for_h1 class
//

#include <input/one_line.h>
#include <output/string.h>
#include <wiki_to/html.h>


rcstring
wiki_to::look_for_heading_one()
{
    //
    // We are looking for the first text in the file, to see whether it
    // is a level one heading or not.  If it is, we extract it from the
    // text.  If it isn't, we return the empty string.
    //
    for (;;)
    {
	int c = isp->getch();
	if (c < 0)
	    return "";
	if (c == '#')
	{
	    // toss leading comments
	    for (;;)
	    {
		c = isp->getch();
		if (c < 0 || c == '\n')
		    break;
	    }
	    continue;
	}
	if (c == '\n')
	    continue;
	if (c != '!')
	{
	    isp->ungetc(c);
	    return "";
	}
	isp->ungetc(c);
	break;
    }

    //
    // We create a special input instance which only ever reads up to
    // the first newline, and after that insists that there is no more
    // input.  We make a special output instance which writes data to
    // a string, and then we translate our cropped input into to our
    // string output.  Then we just return the translated string.
    //
    input_one_line fake_in(*isp);
    output_string fake_out;
    wiki_to *translator = self_factory(fake_in, fake_out);
    translator->translate();
    delete translator;
    return fake_out.mkstr();
}
