//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to impliment the wiki_to_man class
//

#pragma implementation "wiki_to_man"

#include <output.h>
#include <wiki_to/man.h>
#include <wiki_mode/groff_anchor.h>
#include <wiki_mode/groff_heading.h>
#include <wiki_mode/groff_pre.h>
#include <wiki_mode/man_font/bold.h>
#include <wiki_mode/man_font/italics.h>
#include <wiki_mode/man_font/typewriter.h>
#include <wiki_mode/paragraph/groff.h>


wiki_to_man::~wiki_to_man()
{
}


wiki_to_man::wiki_to_man(input &is, output &os) :
    wiki_to(is, os)
{
}


wiki_mode *
wiki_to_man::italics_factory()
{
    return new wiki_mode_man_font_italics(osp);
}


wiki_mode *
wiki_to_man::bold_factory()
{
    return new wiki_mode_man_font_bold(osp);
}


wiki_mode *
wiki_to_man::anchor_factory(const rcstring &destination)
{
    return new wiki_mode_groff_anchor(osp, destination);
}


wiki_mode *
wiki_to_man::typewriter_factory()
{
    return new wiki_mode_man_font_typewriter(osp);
}


wiki_mode *
wiki_to_man::heading_factory(int level)
{
    return new wiki_mode_groff_heading(osp, level);
}


wiki_mode *
wiki_to_man::preformatted_factory()
{
    return new wiki_mode_groff_pre(osp);
}


void
wiki_to_man::putch(char cc)
{
    unsigned char c = cc;
    switch (c)
    {
    case '\t':
    case ' ':
	if (!osp->start_of_line())
	    osp->putch(' ');
	break;

    case '\n':
	bol();
	break;

    case '.':
    case '\'':
	if (osp->start_of_line())
	    osp->puts("\\&");
	osp->putch(c);
	break;

    case '\\':
	osp->puts("\\e");
	break;

              case '!': case '"': case '#':
    case '$': case '%': case '&':
    case '(': case ')': case '*': case '+':
    case ',': case '-':           case '/':
    case '0': case '1': case '2': case '3':
    case '4': case '5': case '6': case '7':
    case '8': case '9': case ':': case ';':
    case '<': case '=': case '>': case '?':
    case '@': case 'A': case 'B': case 'C':
    case 'D': case 'E': case 'F': case 'G':
    case 'H': case 'I': case 'J': case 'K':
    case 'L': case 'M': case 'N': case 'O':
    case 'P': case 'Q': case 'R': case 'S':
    case 'T': case 'U': case 'V': case 'W':
    case 'X': case 'Y': case 'Z': case '[':
              case ']': case '^': case '_':
    case '`': case 'a': case 'b': case 'c':
    case 'd': case 'e': case 'f': case 'g':
    case 'h': case 'i': case 'j': case 'k':
    case 'l': case 'm': case 'n': case 'o':
    case 'p': case 'q': case 'r': case 's':
    case 't': case 'u': case 'v': case 'w':
    case 'x': case 'y': case 'z': case '{':
    case '|': case '}': case '~':
	osp->putch(c);

    default:
	// Discard unprintable characters
	break;
    }
}


wiki_to *
wiki_to_man::self_factory(input &is, output &os)
{
    return new wiki_to_man(is, os);
}


void
wiki_to_man::bol()
{
    if (!osp->start_of_line())
	osp->putch('\n');
}


wiki_mode *
wiki_to_man::paragraph_factory()
{
    return new wiki_mode_paragraph_groff(osp);
}
