//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: interface definition for lib/wiki_to/man.cc
//

#ifndef LIB_WIKI_TO_MAN_H
#define LIB_WIKI_TO_MAN_H

#pragma interface "wiki_to_man"

#include <wiki_to.h>

/**
  * The wiki_to_man class is used to represent the scurrent state of a
  * wiki page to man page translator.
  */
class wiki_to_man:
    public wiki_to
{
public:
    /**
      * The destructor.
      */
    virtual ~wiki_to_man();

    /**
      * The constructor.
      *
      * @param is
      *     The input file to read.
      * @param os
      *     The output stream to write.  It's probably a file, but it
      *     could be anything.
      */
    wiki_to_man(input &is, output &os);

    // See base class for documentation.
    wiki_mode *italics_factory();

    // See base class for documentation.
    wiki_mode *bold_factory();

    // See base class for documentation.
    wiki_mode *typewriter_factory();

    // See base class for documentation.
    wiki_mode *anchor_factory(const rcstring &destination);

    // See base class for documentation.
    wiki_mode *heading_factory(int level);

    // See base class for documentation.
    wiki_mode *preformatted_factory();

    // See base class for documentation.
    wiki_to *self_factory(input&, output&);

    // See base class for documentation.
    wiki_mode *paragraph_factory();

    // See base class for documentation.
    void putch(char c);

private:
    /**
     * The bol method is used to ensure that the output is positioned
     * and the beginning of a line.
     */
    void bol();

    /**
      * The default constructor.  Do not use.
      */
    wiki_to_man();

    /**
      * The copy constructor.  Do not use.
      */
    wiki_to_man(const wiki_to_man &);

    /**
      * The assignment operator.  Do not use.
      */
    wiki_to_man &operator=(const wiki_to_man &);
};

#endif // LIB_WIKI_TO_MAN_H
