//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to impliment the wiki_word class
//

#include <cctype>
#include <cstring>

#include <rcstring/accumulator.h>
#include <wiki_word.h>


rcstring
wiki_word_sanitizer(const rcstring &s)
{
    static rcstring_accumulator tmp;
    tmp.clear();
    bool first = true;
    const char *cp = s.c_str();
    for (;;)
    {
	unsigned char c = *cp++;
	switch (c)
	{
	case '\0':
	    if (tmp.size() == 1 && tmp.back() == '/')
		return tmp.mkstr();
	    while (!tmp.empty() && 0 != strchr("_/", tmp.back()))
		tmp.pop_back();
	    return tmp.mkstr();

	case '/':
	    while (!tmp.empty() && 0 != strchr("_/", tmp.back()))
		tmp.pop_back();
	    tmp.push_back('/');
	    first = true;
	    break;

	case '0': case '1': case '2': case '3': case '4':
	case '5': case '6': case '7': case '8': case '9':
	    tmp.push_back(c);
	    first = false;
	    break;

	case 'A': case 'B': case 'C': case 'D': case 'E': case 'F': case 'G':
	case 'H': case 'I': case 'J': case 'K': case 'L': case 'M': case 'N':
	case 'O': case 'P': case 'Q': case 'R': case 'S': case 'T': case 'U':
	case 'V': case 'W': case 'X': case 'Y': case 'Z':
	    tmp.push_back(tolower(c));
	    first = false;
	    break;

	case 'a': case 'b': case 'c': case 'd': case 'e': case 'f': case 'g':
	case 'h': case 'i': case 'j': case 'k': case 'l': case 'm': case 'n':
	case 'o': case 'p': case 'q': case 'r': case 's': case 't': case 'u':
	case 'v': case 'w': case 'x': case 'y': case 'z':
	    tmp.push_back(c);
	    first = false;
	    break;

	default:
	    if (!first && tmp.back() != '_')
		tmp.push_back('_');
	    break;
	}
    }
}


rcstring
wiki_word_pretty(const rcstring &s)
{
    rcstring_accumulator acc;
    const char *cp = s.c_str();
    for (;;)
    {
	unsigned char c = *cp++;
	if (!c)
	    break;
	if (c == '/' || c == '_' || !isprint(c))
	    c = ' ';
	acc.push_back(c);
    }
    return acc.mkstr().trim().capitalize();
}
