//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: operating start point
//

#include <config.h>

#include <cstdio>
#include <cstdlib>
#include <unistd.h>
#include <getopt.h>

#include <configuration.h>
#include <progname.h>
#include <versn_stamp.h>

static struct option options[] =
{
    { "sysconfdir",    0, 0, 'e' },
    { "sysconf",       0, 0, 'e' },
    { "etc",           0, 0, 'e' },
    { "version",       0, 0, 'V' },
    { "localstatedir", 0, 0, 'v' },
    { "var",           0, 0, 'v' },
    { 0 }
};


static void
usage()
{
    fprintf(stderr, "Usage: %s <option>\n", progname_get());
    fprintf(stderr, "    --var     # the directory wiki pages live in\n"
                    "    --etc     # the directory config files live in\n"
                    "    --version # print the version number\n"
	);
    exit(1);
}


int
main(int argc, char **argv)
{
    progname_set(argv[0]);
    bool done = false;
    for (;;)
    {
	int c = getopt_long(argc, argv, "evV", options, 0);
	if (c < 0)
	    break;
	switch (c)
	{
	case 'e':
	    printf("%s\n", config.get_sysconfdir().c_str());
	    done = true;
	    break;

	case 'v':
	    printf("%s\n", config.get_localstatedir().c_str());
	    done = true;
	    break;

	case 'V':
	    printf("Quickie version %s\n", version_stamp());
	    printf("Copyright %s Peter Miller\n", copyright_years());
	    done = true;
	    break;

	default:
	    usage();
	    // NOTREACHED
	}
    }
    if (!done || optind < argc)
    {
	usage();
	// NOTREACHED
    }
    return 0;
}
