//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: operating system entry point
//

#include <clocale>
#include <cstdlib>
#include <cstdio>

#include <cgi.h>
#include <configuration.h>
#include <file.h>
#include <post_install.h>
#include <progname.h>
#include <quit/cgi.h>

static quit_cgi whinger;


int
main(int argc, char **argv)
{
    //
    // This is a CGI program.  For security reasons, we *must*
    // ignore all command line arguments.  This is because a
    // cunning user could specify just about anything at all using
    //    http://.../cgi-bin/quickie?arg+arg+...
    // so if we are to be customized in any way, it will have to be at
    // ./configure time, or through environment variables.
    //
    progname_set(argv[0]);
    (void)argc;

    //
    // Give the poor sap a clue.
    //
    if (!getenv("REQUEST_METHOD"))
    {
	printf
	(
	    "You appear to be running %s from the command line.  This program\n"
	    "is designed to be run as a CGI script by your web server.\n",
	    progname_get()
	);
	post_install_speil();
	return 1;
    }

    //
    // Set the appropriate quit style.
    //
    quit::set_quitter(whinger);

    //
    // Make sure the isprint() etc functions are not affected by the
    // user's locale settings (if any).
    //
    setlocale(LC_ALL, "C");

    //
    // If we have been configured to do so, chroot into the localstatedir
    //
    config.chroot();

    //
    // Get the PATH_INFO environment variable, to figure out what sort
    // of object they are querying.
    //
    file *fp = file::factory(gateway.get_path_info());

    //
    // There are a few things they could be asking,
    // controlled by the REQUEST_METHOD environment variable.
    // This prints its results on the standard output.
    //
    fp->request();
    delete fp;

    //
    // All done.  Report success.
    //
    quitter.exit(0);
    return 0;
}
