//
//	quickie - a small fast C++ Wiki Wiki
//	Copyright (C) 2005 Peter Miller
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: operating system entry point
//

#include <arglex.h>
#include <input/file.h>
#include <input/stdin.h>
#include <input/uudecode.h>
#include <output/file.h>
#include <output/stdout.h>


static input *
open_input(const rcstring &infile)
{
    if (infile.empty() || infile == "-")
	return new input_stdin();
    return new input_file(infile);
}


static output *
open_output(const rcstring &outfile)
{
    if (outfile.empty() || outfile == "-")
	return new output_stdout();
    return new output_file(outfile);
}


int
main(int argc, char **argv)
{
    arglex cmdline(argc, argv);
    cmdline.usage_tail_set("[ <infile> [ <outfile> ]]");
    cmdline.token_first();
    rcstring infile;
    rcstring outfile;
    while (cmdline.token_cur() != arglex::token_eoln)
    {
	switch (cmdline.token_cur())
	{
	case arglex::token_stdio:
	    if (infile.empty())
		infile = "-";
	    else if (outfile.empty())
		outfile = "-";
	    else
		cmdline.usage();
	    break;

	case arglex::token_string:
	    if (infile.empty())
		infile = cmdline.value_string();
	    else if (outfile.empty())
		outfile = cmdline.value_string();
	    else
		cmdline.usage();
	    break;

	default:
	    cmdline.bad_argument();
	    // NOTREACHED
	}
	cmdline.token_next();
    }

    //
    // Open all of the files
    //
    input *ip = open_input(infile);
    ip = new input_uudecode(ip);
    output *op = open_output(outfile);

    //
    // Copy the input to the output.
    //
    *op << *ip;

    //
    // All done.  Close everything and report success
    //
    delete ip;
    delete op;
    return 0;
}
