#!/bin/sh
#
#	quickie - a small fast C++ Wiki Wiki
#	Copyright (C) 2005 Peter Miller
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
#
# MANIFEST: Test the preview functionality
#
here=`pwd`
test $? -eq 0 || exit 2
work=${TMP_DIR-/tmp}/$$

tear_down()
{
	cd $here
	rm -rf $work
}

pass()
{
	tear_down
	echo PASSED
	exit 0
}

fail()
{
	tear_down
	echo 'FAILED test of the preview functionality'
	exit 1
}

no_result()
{
	tear_down
	echo 'NO RESULT for test of the preview functionality'
	exit 2
}

trap "no_result" 1 2 3 15

bin=$here/${1-.}/bin
mkdir $work $work/var $work/etc
test $? -eq 0 || no_result
cd $work
test $? -eq 0 || no_result

#
# We can't pass options on the command line, because they could be
# abused by a remote client.  Instead, we configure things using
# environment variables.
#
QUICKIE_LOCALSTATEDIR=$work/var ; export QUICKIE_LOCALSTATEDIR
QUICKIE_SYSCONFDIR=$work/etc ; export QUICKIE_SYSCONFDIR

cat > etc/quickie.conf << 'fubar'
sidebar-layout: none
fubar
test $? -eq 0 || no_result

cat > var/index.html << 'fubar'
<html><body>Hello, World!</body></html>
fubar
test $? -eq 0 || no_result

cat > test.ok << 'fubar'
Content-Type: text/html

<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0//EN" "">
<HTML><HEAD>
<TITLE>Preview Blah</TITLE>
<LINK REL="stylesheet" HREF="admin/default.css" TYPE="text/css">
</HEAD><BODY>
<H1 CLASS="administration">Preview Blah</H1>
<P CLASS="warning">Warning: this is a preview.  Your
editing has not been saved.  To save, hit the Back button
in your broswer, and then click on the Save button.</P>
<HR>
<P CLASS="preview">This is the text being saved.</P>
<HR>
<P CLASS="warning">Warning: this is a preview.  Your
editing has not been saved.  To save, hit the Back button
in your broswer, and then click on the Save button.</P>
</BODY></HTML>
fubar
test $? -eq 0 || no_result

PATH_INFO=/blah \
QUERY_STRING='action=preview&content=This+is+the+text+being+saved.' \
SERVER_NAME=localhost \
SERVER_PORT=80 \
REQUEST_METHOD=GET \
SCRIPT_NAME=/cgi-bin/quickie \
$bin/quickie > test.out
if test $? -ne 0
then
    cat test.out
    fail
fi

diff test.ok test.out
test $? -eq 0 || fail

#
# validate the output
#
if validate -v > /dev/null 2>&1
then
    sed '1,2d' < test.out > test.out.2
    test $? -eq 0 || no_result

    validate test.out.2
    test $? -eq 0 || fail
fi

#
# The things tested here, worked.
# No other guarantees are made.
#
pass
