#!/bin/sh
#
#	quickie - a small fast C++ Wiki Wiki
#	Copyright (C) 2005 Peter Miller
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
#
# MANIFEST: Test the edit query functionality
#
here=`pwd`
test $? -eq 0 || exit 2
work=${TMP_DIR-/tmp}/$$

tear_down()
{
	cd $here
	rm -rf $work
}

pass()
{
	tear_down
	echo PASSED
	exit 0
}

fail()
{
	tear_down
	echo 'FAILED test of the edit query functionality'
	exit 1
}

no_result()
{
	tear_down
	echo 'NO RESULT for test of the edit query functionality'
	exit 2
}

trap "no_result" 1 2 3 15

bin=$here/${1-.}/bin
mkdir $work $work/var $work/etc
test $? -eq 0 || no_result
cd $work
test $? -eq 0 || no_result

#
# We can't pass options on the command line, because they could be
# abused by a remote client.  Instead, we configure things using
# environment variables.
#
QUICKIE_LOCALSTATEDIR=$work/var ; export QUICKIE_LOCALSTATEDIR
QUICKIE_SYSCONFDIR=$work/etc ; export QUICKIE_SYSCONFDIR

cat > etc/quickie.conf << 'fubar'
show-mod-times: false
sidebar-layout: left
anonymous-user-edit: true
fubar
test $? -eq 0 || no_result

cat > var/index.wiki << 'fubar'
Welcome to Quickie Wiki,
the C++ Wiki Wiki.

This first page can be replaced, like all other wiki pages, by using the
"Edit" link you see at the bottom of this page.

[quickie|Quicki Wiki Documentation].
fubar
test $? -eq 0 || no_result

cat > var/sidebar.wiki << 'fubar'
This is the sidebar.  You can put links to useful places here.

There are several [admin|system] pages, including things like the current [admin/settings|configuration] settings.

To edit this text, press the "Edit" link you see below.
fubar
test $? -eq 0 || no_result

cat > test.ok << 'fubar'
Content-Type: text/html

<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0//EN" "">
<HTML><HEAD>
<TITLE>Edit Index</TITLE>
<LINK REL="stylesheet" HREF="admin/default.css" TYPE="text/css">
</HEAD><BODY>
<TABLE>
<TR>
<TD VALIGN="TOP" CLASS="sidebar" STYLE="width: 100px">
<P CLASS="sidebar">This is the sidebar.  You can put links to useful places here.</P>
<P CLASS="sidebar">There are several <A
HREF="admin/index"
CLASS="sidebar">system</A> pages, including things like the current <A
HREF="admin/settings"
CLASS="sidebar">configuration</A> settings.</P>
<P CLASS="sidebar">To edit this text, press the &quot;Edit&quot; link you see below.
</P>
<P CLASS="sidebar">
<A HREF="sidebar?edit" CLASS="sidebar">Edit</A> this
<A HREF="sidebar" CLASS="sidebar">sidebar</A>.
</P>
</TD>
<TD VALIGN="TOP" CLASS="content">
<H1 CLASS="administration">Edit Index</H1>
<FORM ACTION="http://localhost/cgi-bin/quickie/index" METHOD="POST">
<P CLASS="administration">
<TEXTAREA NAME="content" ROWS="24" COLS="80">Welcome to Quickie Wiki,
the C++ Wiki Wiki.

This first page can be replaced, like all other wiki pages, by using the
&quot;Edit&quot; link you see at the bottom of this page.

[quickie|Quicki Wiki Documentation].
</TEXTAREA><BR>
<INPUT TYPE="SUBMIT" name="action" value="Save">
<INPUT TYPE="SUBMIT" name="action" value="Preview">
<INPUT TYPE="SUBMIT" name="action" value="Cancel">
</P>
</FORM>
</TD>
</TR>
</TABLE>
</BODY></HTML>
fubar
test $? -eq 0 || no_result

PATH_INFO=/index \
QUERY_STRING=edit \
SERVER_NAME=localhost \
SERVER_PORT=80 \
REQUEST_METHOD=GET \
SCRIPT_NAME=/cgi-bin/quickie \
$bin/quickie > test.out
if test $? -ne 0
then
    cat test.out
    fail
fi

diff test.ok test.out
test $? -eq 0 || fail

#
# validate the output
#
if validate -v > /dev/null 2>&1
then
    sed '1,2d' < test.out > test.out.2
    test $? -eq 0 || no_result

    validate test.out.2
    test $? -eq 0 || fail
fi

#
# The things tested here, worked.
# No other guarantees are made.
#
pass
