#!/bin/sh
#
#	quickie - a small fast C++ Wiki Wiki
#	Copyright (C) 2005 Peter Miller
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
#
# MANIFEST: Test the catalogue functionality
#
here=`pwd`
test $? -eq 0 || exit 2
work=${TMP_DIR-/tmp}/$$

tear_down()
{
	cd $here
	rm -rf $work
}

pass()
{
	tear_down
	echo PASSED
	exit 0
}

fail()
{
	tear_down
	echo 'FAILED test of the catalogue functionality'
	exit 1
}

no_result()
{
	tear_down
	echo 'NO RESULT for test of the catalogue functionality'
	exit 2
}

trap "no_result" 1 2 3 15

bin=$here/${1-.}/bin
mkdir $work $work/var $work/var/subdir $work/etc
test $? -eq 0 || no_result
cd $work
test $? -eq 0 || no_result

#
# We can't pass options on the command line, because they could be
# abused by a remote client.  Instead, we configure things using
# environment variables.
#
QUICKIE_LOCALSTATEDIR=$work/var ; export QUICKIE_LOCALSTATEDIR
QUICKIE_SYSCONFDIR=$work/etc ; export QUICKIE_SYSCONFDIR

cat > etc/quickie.conf << 'fubar'
show-mod-times: false
sidebar-layout: none
fubar
test $? -eq 0 || no_result

cat > var/index.wiki << 'fubar'
index
fubar
test $? -eq 0 || no_result

cat > var/file2.wiki << 'fubar'
file2
fubar
test $? -eq 0 || no_result

cat > var/subdir/file3.wiki << 'fubar'
file3
fubar
test $? -eq 0 || no_result

cat > test.ok << 'fubar'
Content-Type: text/html

<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0//EN" "">
<HTML><HEAD>
<TITLE>Catalogue of Wiki Files</TITLE>
<LINK REL="stylesheet" HREF="default.css" TYPE="text/css">
</HEAD><BODY>
<H1 CLASS="administration">Catalogue of Wiki Files</H1>
<P CLASS="administration" STYLE="text-align: center;"><A HREF="#F" CLASS="administration">F</A> -
<A HREF="#I" CLASS="administration">I</A> -
<A HREF="#S" CLASS="administration">S</A></P>
<H2 CLASS="administration">- <A NAME="F" CLASS="administration">F</A> -</H2>
<P CLASS="administration">
<A HREF="../file2" CLASS="administration">File2</A></P>
<H2 CLASS="administration">- <A NAME="I" CLASS="administration">I</A> -</H2>
<P CLASS="administration">
<A HREF="../index" CLASS="administration">Index</A></P>
<H2 CLASS="administration">- <A NAME="S" CLASS="administration">S</A> -</H2>
<P CLASS="administration">
<A HREF="../subdir/file3" CLASS="administration">Subdir File3</A></P>
</BODY></HTML>
fubar
test $? -eq 0 || no_result

PATH_INFO=/admin/catalogue \
QUERY_STRING= \
SERVER_NAME=localhost \
SERVER_PORT=80 \
REQUEST_METHOD=GET \
SCRIPT_NAME=/cgi-bin/quickie \
$bin/quickie > test.out
if test $? -ne 0
then
    cat test.out
    fail
fi

diff test.ok test.out
test $? -eq 0 || fail

#
# validate the output
#
if validate -v > /dev/null 2>&1
then
    sed '1,2d' < test.out > test.out.2
    test $? -eq 0 || no_result

    validate test.out.2
    test $? -eq 0 || fail
fi

#
# The things tested here, worked.
# No other guarantees are made.
#
pass
