#!/bin/sh
#
#	quickie - a small fast C++ Wiki Wiki
#	Copyright (C) 2005 Peter Miller
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
#
# MANIFEST: Test the revert functionality
#
here=`pwd`
test $? -eq 0 || exit 2
work=${TMP_DIR-/tmp}/$$

tear_down()
{
	cd $here
	rm -rf $work
}

pass()
{
	tear_down
	echo PASSED
	exit 0
}

fail()
{
	tear_down
	echo 'FAILED test of the revert functionality'
	exit 1
}

no_result()
{
	tear_down
	echo 'NO RESULT for test of the revert functionality'
	exit 2
}

trap "no_result" 1 2 3 15

bin=$here/${1-.}/bin
mkdir $work $work/var $work/etc
test $? -eq 0 || no_result
cd $work
test $? -eq 0 || no_result

#
# We can't pass options on the command line, because they could be
# abused by a remote client.  Instead, we configure things using
# environment variables.
#
QUICKIE_LOCALSTATEDIR=$work/var ; export QUICKIE_LOCALSTATEDIR
QUICKIE_SYSCONFDIR=$work/etc ; export QUICKIE_SYSCONFDIR
REMOTE_ADDR=127.0.0.1 ; export REMOTE_ADDR

cat > etc/quickie.conf << 'fubar'
show-mod-times: false
sidebar-layout: none
anonymous-user-edit: true
fubar
test $? -eq 0 || no_result

cat > test.ok << 'fubar'
Content-Type: text/html
Content-Length: 419

<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0//EN" "">
<HTML><HEAD>
<TITLE>Test</TITLE>
<LINK REL="stylesheet" HREF="admin/default.css" TYPE="text/css">
</HEAD><BODY>
<H1 CLASS="content">Test</H1>
<P CLASS="content">This is version one.
</P>
<HR CLASS="content">
<P CLASS="content"><A HREF="test?edit" CLASS="content">Edit this page</A>.
<A HREF="test?history" CLASS="content">Historical versions</A>.</P>
</BODY></HTML>
fubar
test $? -eq 0 || no_result

PATH_INFO=/test \
QUERY_STRING='save&content=This+is+version+one.' \
SERVER_NAME=localhost \
SERVER_PORT=80 \
REQUEST_METHOD=GET \
SCRIPT_NAME=/cgi-bin/quickie \
$bin/quickie > test.out
if test $? -ne 0
then
    cat test.out
    fail
fi

diff test.ok test.out
test $? -eq 0 || fail

#
# validate the output
#
if validate -v > /dev/null 2>&1
then
    sed '1,2d' < test.out > test.out.2
    test $? -eq 0 || no_result

    validate test.out.2
    test $? -eq 0 || fail
fi

# -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- --

cat > test.ok << 'fubar'
Content-Type: text/html
Content-Length: 419

<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0//EN" "">
<HTML><HEAD>
<TITLE>Test</TITLE>
<LINK REL="stylesheet" HREF="admin/default.css" TYPE="text/css">
</HEAD><BODY>
<H1 CLASS="content">Test</H1>
<P CLASS="content">This is version two.
</P>
<HR CLASS="content">
<P CLASS="content"><A HREF="test?edit" CLASS="content">Edit this page</A>.
<A HREF="test?history" CLASS="content">Historical versions</A>.</P>
</BODY></HTML>
fubar
test $? -eq 0 || no_result

PATH_INFO=/test \
QUERY_STRING='save&content=This+is+version+two.' \
SERVER_NAME=localhost \
SERVER_PORT=80 \
REQUEST_METHOD=GET \
SCRIPT_NAME=/cgi-bin/quickie \
$bin/quickie > test.out
if test $? -ne 0
then
    cat test.out
    fail
fi

diff test.ok test.out
test $? -eq 0 || fail


#
# validate the output
#
if validate -v > /dev/null 2>&1
then
    sed '1,3d' < test.out > test.out.2
    test $? -eq 0 || no_result

    validate test.out.2
    test $? -eq 0 || fail
fi
# -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- --

cat > test.ok << 'fubar'
Content-Type: text/html
Content-Length: 421

<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0//EN" "">
<HTML><HEAD>
<TITLE>Test</TITLE>
<LINK REL="stylesheet" HREF="admin/default.css" TYPE="text/css">
</HEAD><BODY>
<H1 CLASS="content">Test</H1>
<P CLASS="content">This is version three.
</P>
<HR CLASS="content">
<P CLASS="content"><A HREF="test?edit" CLASS="content">Edit this page</A>.
<A HREF="test?history" CLASS="content">Historical versions</A>.</P>
</BODY></HTML>
fubar
test $? -eq 0 || no_result

PATH_INFO=/test \
QUERY_STRING='save&content=This+is+version+three.' \
SERVER_NAME=localhost \
SERVER_PORT=80 \
REQUEST_METHOD=GET \
SCRIPT_NAME=/cgi-bin/quickie \
$bin/quickie > test.out
if test $? -ne 0
then
    cat test.out
    fail
fi

diff test.ok test.out
test $? -eq 0 || fail

#
# validate the output
#
if validate -v > /dev/null 2>&1
then
    sed '1,3d' < test.out > test.out.2
    test $? -eq 0 || no_result

    validate test.out.2
    test $? -eq 0 || fail
fi

# -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- --

cat > test.ok << 'fubar'
Content-Type: text/html

<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0//EN" "">
<HTML><HEAD>
<TITLE>History of Test</TITLE>
<LINK REL="stylesheet" HREF="admin/default.css" TYPE="text/css">
</HEAD><BODY>
<H1 CLASS="administration">History of Test</H1>
<TABLE CLASS="administration">
<TR CLASS="administration">
<TH CLASS="administration">Version</TH>
<TH CLASS="administration">Date and Time</TH>
<TH CLASS="administration">Who</TH>
<TH CLASS="administration">Revert?</TH>
</TR>
<TR CLASS="administration">
<TD ALIGN="CENTER" CLASS="administration">3</TD>
<TD ALIGN="CENTER" CLASS="administration">date_and_time</TD>
<TD ALIGN="CENTER" CLASS="administration">127.0.0.1</TD>
<TD ALIGN="CENTER" CLASS="administration"></TD>
</TR>
<TR CLASS="administration">
<TD ALIGN="CENTER" CLASS="administration">2</TD>
<TD ALIGN="CENTER" CLASS="administration">date_and_time</TD>
<TD ALIGN="CENTER" CLASS="administration">127.0.0.1</TD>
<TD ALIGN="CENTER" CLASS="administration"><A HREF="test?action=edit&amp;version=2" CLASS="administration">revert</A></TD>
</TR>
<TR CLASS="administration">
<TD ALIGN="CENTER" CLASS="administration">1</TD>
<TD ALIGN="CENTER" CLASS="administration">date_and_time</TD>
<TD ALIGN="CENTER" CLASS="administration">127.0.0.1</TD>
<TD ALIGN="CENTER" CLASS="administration"><A HREF="test?action=edit&amp;version=1" CLASS="administration">revert</A></TD>
</TR>
</TABLE>
</BODY></HTML>
fubar
test $? -eq 0 || no_result

PATH_INFO=/test \
QUERY_STRING='history' \
SERVER_NAME=localhost \
SERVER_PORT=80 \
REQUEST_METHOD=GET \
SCRIPT_NAME=/cgi-bin/quickie \
$bin/quickie > test.out.almost
if test $? -ne 0
then
    cat test.out
    fail
fi

sed 's|>..., .. ... .... ..:..:[^<]*|>date_and_time|' \
    < test.out.almost > test.out
test $? -eq 0 || no_result

diff test.ok test.out
test $? -eq 0 || fail

#
# validate the output
#
if validate -v > /dev/null 2>&1
then
    sed '1,2d' < test.out > test.out.2
    test $? -eq 0 || no_result

    validate test.out.2
    test $? -eq 0 || fail
fi

# -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- --

cat > test.ok << 'fubar'
Content-Type: text/html

<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0//EN" "">
<HTML><HEAD>
<TITLE>Edit Test</TITLE>
<LINK REL="stylesheet" HREF="admin/default.css" TYPE="text/css">
</HEAD><BODY>
<H1 CLASS="administration">Edit Test</H1>
<FORM ACTION="http://localhost/cgi-bin/quickie/test" METHOD="POST">
<P CLASS="administration">
<TEXTAREA NAME="content" ROWS="24" COLS="80">This is version one.
</TEXTAREA><BR>
<INPUT TYPE="SUBMIT" name="action" value="Save">
<INPUT TYPE="SUBMIT" name="action" value="Preview">
<INPUT TYPE="SUBMIT" name="action" value="Cancel">
</P>
</FORM>
</BODY></HTML>
fubar
test $? -eq 0 || no_result

PATH_INFO=/test \
QUERY_STRING='edit&version=1' \
SERVER_NAME=localhost \
SERVER_PORT=80 \
REQUEST_METHOD=GET \
SCRIPT_NAME=/cgi-bin/quickie \
$bin/quickie > test.out
if test $? -ne 0
then
    cat test.out
    fail
fi

diff test.ok test.out
test $? -eq 0 || fail

#
# validate the output
#
if validate -v > /dev/null 2>&1
then
    sed '1,2d' < test.out > test.out.2
    test $? -eq 0 || no_result

    validate test.out.2
    test $? -eq 0 || fail
fi

#
# The things tested here, worked.
# No other guarantees are made.
#
pass
