#!/bin/sh
#
#	quickie - a small fast C++ Wiki Wiki
#	Copyright (C) 2005 Peter Miller
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
#
# MANIFEST: Test the admin image files functionality
#
here=`pwd`
test $? -eq 0 || exit 2
work=${TMP_DIR-/tmp}/$$

tear_down()
{
	cd $here
	rm -rf $work
}

pass()
{
	tear_down
	echo PASSED
	exit 0
}

fail()
{
	tear_down
	echo 'FAILED test of the admin image files functionality'
	exit 1
}

no_result()
{
	tear_down
	echo 'NO RESULT for test of the admin image files functionality'
	exit 2
}

trap "no_result" 1 2 3 15

bin=$here/${1-.}/bin
mkdir -p $work/var/admin $work/etc
test $? -eq 0 || no_result
cd $work
test $? -eq 0 || no_result

#
# We can't pass options on the command line, because they could be
# abused by a remote client.  Instead, we configure things using
# environment variables.
#
QUICKIE_LOCALSTATEDIR=$work/var ; export QUICKIE_LOCALSTATEDIR
QUICKIE_SYSCONFDIR=$work/etc ; export QUICKIE_SYSCONFDIR

cat > etc/quickie.conf << 'fubar'
show-mod-times: false
sidebar-layout: none
fubar
test $? -eq 0 || no_result

cat > img-file-in.uue << 'fubar'
begin 644 var/admin/external.png
MB5!.1PT*&@H````-24A$4@````4````&`0,````Q-<8(````!E!,5$4``P#_
M``!<7_?R`````7123E,`0.;89@````%B2T=$`(@%'4@````4241!5`C78ZA@
?L&"H8'C!<(#A```1_`.1M(')H@````!)14Y$KD)@@@``
`
end
fubar
test $? -eq 0 || no_result

$bin/quickie_uudecode img-file-in.uue var/admin/external.png
test $? -eq 0 || no_result

cat > test.ok << 'fubar'
Content-Type: image/png
Content-Length: 121

fubar
test $? -eq 0 || no_result

cat var/admin/external.png >> test.ok
test $? -eq 0 || no_result

PATH_INFO=/admin/external.png \
QUERY_STRING= \
SERVER_NAME=localhost \
SERVER_PORT=80 \
REQUEST_METHOD=GET \
SCRIPT_NAME=/cgi-bin/quickie \
$bin/quickie > test.out
if test $? -ne 0
then
    cat test.out
    fail
fi

cmp test.ok test.out
test $? -eq 0 || fail

#
# The things tested here, worked.
# No other guarantees are made.
#
pass
