#!/bin/sh
#
#	quickie - a small fast C++ Wiki Wiki
#	Copyright (C) 2005 Peter Miller
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
#
# MANIFEST: Test the new-user functionality
#
here=`pwd`
test $? -eq 0 || exit 2
work=${TMP_DIR-/tmp}/$$

tear_down()
{
	cd $here
	rm -rf $work
}

pass()
{
	tear_down
	echo PASSED
	exit 0
}

fail()
{
	tear_down
	echo 'FAILED test of the new-user functionality'
	exit 1
}

no_result()
{
	tear_down
	echo 'NO RESULT for test of the new-user functionality'
	exit 2
}

trap "no_result" 1 2 3 15

bin=$here/${1-.}/bin
mkdir $work $work/var $work/etc
test $? -eq 0 || no_result
cd $work
test $? -eq 0 || no_result

#
# We can't pass options on the command line, because they could be
# abused by a remote client.  Instead, we configure things using
# environment variables.
#
QUICKIE_LOCALSTATEDIR=$work/var ; export QUICKIE_LOCALSTATEDIR
QUICKIE_SYSCONFDIR=$work/etc ; export QUICKIE_SYSCONFDIR
REMOTE_ADDR=127.0.0.1 ; export REMOTE_ADDR

cat > etc/quickie.conf << 'fubar'
show-mod-times: false
sidebar-layout: none
fubar
test $? -eq 0 || no_result

cat > var/index.html << 'fubar'
<html><body>Hello, World!</body></html>
fubar
test $? -eq 0 || no_result

cat > test.ok << 'fubar'
Set-Cookie: quickie-user-name=pmiller; path=/
Set-Cookie: quickie-user-key=XXXXXXXXXXXXXXXXXXXX; path=/
Content-Type: text/html

<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0//EN" "">
<HTML><HEAD>
<TITLE>Create New User</TITLE>
<LINK REL="stylesheet" HREF="default.css" TYPE="text/css">
</HEAD><BODY>
<H1>Create New User</H1>
<P CLASS="administration">User pmiller created successfully.</P>
</BODY></HTML>
fubar
test $? -eq 0 || no_result

PATH_INFO=/admin/new_user \
QUERY_STRING='submit=Submit&fullname=Peter+Miller&email=millerp@canb.auug.org.au&name=pmiller&pwd1=asif&pwd2=asif' \
SERVER_NAME=localhost \
SERVER_PORT=80 \
REQUEST_METHOD=GET \
SCRIPT_NAME=/cgi-bin/quickie \
$bin/quickie > test.out.raw
if test $? -ne 0
then
    cat test.out
    fail
fi

# the key changes every time, so edit it out
sed 's|key=....................|key=XXXXXXXXXXXXXXXXXXXX|' \
    < test.out.raw > test.out
test $? -eq 0 || no_result

diff test.ok test.out
test $? -eq 0 || fail

#
# validate the output
#
if validate -v > /dev/null 2>&1
then
    sed '1,4d' < test.out > test.out.2
    test $? -eq 0 || no_result

    validate test.out.2
    test $? -eq 0 || fail
fi

#
# It was supposed to create a particular file, too,
# to hold info about the user.  We'll have to nobble they key again.
#
cat > test.ok << 'fubar'
Edit: true
Email: millerp@canb.auug.org.au
Fullname: Peter Miller
Key: XXXXXXXXXXXXXXXXXXXX
Name: pmiller
Password: XXXXXXXXXXXXX

fubar
test $? -eq 0 || no_result

sed \
    -e 's|Key: ....................$|Key: XXXXXXXXXXXXXXXXXXXX|' \
    -e 's|Password: .............$|Password: XXXXXXXXXXXXX|' \
    < var/admin/user.db/p/pm/pmiller > test.out
test $? -eq 0 || fail

diff test.ok test.out
test $? -eq 0 || fail

#
# The things tested here, worked.
# No other guarantees are made.
#
pass
